/** \file hdr_gpio.h
 * \brief Header with definition of bits in GPIO control registers
 * \author Freddie Chopin, http://www.freddiechopin.info/
 * \date 2012-04-07
 */

/******************************************************************************
* chip: LPC175x / LPC176x
* compiler: arm-none-eabi-gcc (GNU Tools for ARM Embedded Processors) 4.6.2
* 	20110921 (release) [ARM/embedded-4_6-branch revision 182083]
******************************************************************************/

#ifndef HDR_GPIO_H_
#define HDR_GPIO_H_

#include "hdr/hdr_bitband.h"

/*
+=============================================================================+
| global definitions
+=============================================================================+
*/

#define LPC_GPIO_FIODIR_IN_value			0
#define LPC_GPIO_FIODIR_OUT_value			1
#define LPC_GPIO_FIODIR_mask				1

/*
+-----------------------------------------------------------------------------+
| FIODIR - GPIO port Direction register
+-----------------------------------------------------------------------------+
*/

#define LPC_GPIO_FIODIR_DIR0_bit			0
#define LPC_GPIO_FIODIR_DIR1_bit			1
#define LPC_GPIO_FIODIR_DIR2_bit			2
#define LPC_GPIO_FIODIR_DIR3_bit			3
#define LPC_GPIO_FIODIR_DIR4_bit			4
#define LPC_GPIO_FIODIR_DIR5_bit			5
#define LPC_GPIO_FIODIR_DIR6_bit			6
#define LPC_GPIO_FIODIR_DIR7_bit			7
#define LPC_GPIO_FIODIR_DIR8_bit			8
#define LPC_GPIO_FIODIR_DIR9_bit			9
#define LPC_GPIO_FIODIR_DIR10_bit			10
#define LPC_GPIO_FIODIR_DIR11_bit			11
#define LPC_GPIO_FIODIR_DIR12_bit			12
#define LPC_GPIO_FIODIR_DIR13_bit			13
#define LPC_GPIO_FIODIR_DIR14_bit			14
#define LPC_GPIO_FIODIR_DIR15_bit			15
#define LPC_GPIO_FIODIR_DIR16_bit			16
#define LPC_GPIO_FIODIR_DIR17_bit			17
#define LPC_GPIO_FIODIR_DIR18_bit			18
#define LPC_GPIO_FIODIR_DIR19_bit			19
#define LPC_GPIO_FIODIR_DIR20_bit			20
#define LPC_GPIO_FIODIR_DIR21_bit			21
#define LPC_GPIO_FIODIR_DIR22_bit			22
#define LPC_GPIO_FIODIR_DIR23_bit			23
#define LPC_GPIO_FIODIR_DIR24_bit			24
#define LPC_GPIO_FIODIR_DIR25_bit			25
#define LPC_GPIO_FIODIR_DIR26_bit			26
#define LPC_GPIO_FIODIR_DIR27_bit			27
#define LPC_GPIO_FIODIR_DIR28_bit			28
#define LPC_GPIO_FIODIR_DIR29_bit			29
#define LPC_GPIO_FIODIR_DIR30_bit			30
#define LPC_GPIO_FIODIR_DIR31_bit			31

#define LPC_GPIO_FIODIR_DIR0				(1 << LPC_GPIO_FIODIR_DIR0_bit)
#define LPC_GPIO_FIODIR_DIR1				(1 << LPC_GPIO_FIODIR_DIR1_bit)
#define LPC_GPIO_FIODIR_DIR2				(1 << LPC_GPIO_FIODIR_DIR2_bit)
#define LPC_GPIO_FIODIR_DIR3				(1 << LPC_GPIO_FIODIR_DIR3_bit)
#define LPC_GPIO_FIODIR_DIR4				(1 << LPC_GPIO_FIODIR_DIR4_bit)
#define LPC_GPIO_FIODIR_DIR5				(1 << LPC_GPIO_FIODIR_DIR5_bit)
#define LPC_GPIO_FIODIR_DIR6				(1 << LPC_GPIO_FIODIR_DIR6_bit)
#define LPC_GPIO_FIODIR_DIR7				(1 << LPC_GPIO_FIODIR_DIR7_bit)
#define LPC_GPIO_FIODIR_DIR8				(1 << LPC_GPIO_FIODIR_DIR8_bit)
#define LPC_GPIO_FIODIR_DIR9				(1 << LPC_GPIO_FIODIR_DIR9_bit)
#define LPC_GPIO_FIODIR_DIR10				(1 << LPC_GPIO_FIODIR_DIR10_bit)
#define LPC_GPIO_FIODIR_DIR11				(1 << LPC_GPIO_FIODIR_DIR11_bit)
#define LPC_GPIO_FIODIR_DIR12				(1 << LPC_GPIO_FIODIR_DIR12_bit)
#define LPC_GPIO_FIODIR_DIR13				(1 << LPC_GPIO_FIODIR_DIR13_bit)
#define LPC_GPIO_FIODIR_DIR14				(1 << LPC_GPIO_FIODIR_DIR14_bit)
#define LPC_GPIO_FIODIR_DIR15				(1 << LPC_GPIO_FIODIR_DIR15_bit)
#define LPC_GPIO_FIODIR_DIR16				(1 << LPC_GPIO_FIODIR_DIR16_bit)
#define LPC_GPIO_FIODIR_DIR17				(1 << LPC_GPIO_FIODIR_DIR17_bit)
#define LPC_GPIO_FIODIR_DIR18				(1 << LPC_GPIO_FIODIR_DIR18_bit)
#define LPC_GPIO_FIODIR_DIR19				(1 << LPC_GPIO_FIODIR_DIR19_bit)
#define LPC_GPIO_FIODIR_DIR20				(1 << LPC_GPIO_FIODIR_DIR20_bit)
#define LPC_GPIO_FIODIR_DIR21				(1 << LPC_GPIO_FIODIR_DIR21_bit)
#define LPC_GPIO_FIODIR_DIR22				(1 << LPC_GPIO_FIODIR_DIR22_bit)
#define LPC_GPIO_FIODIR_DIR23				(1 << LPC_GPIO_FIODIR_DIR23_bit)
#define LPC_GPIO_FIODIR_DIR24				(1 << LPC_GPIO_FIODIR_DIR24_bit)
#define LPC_GPIO_FIODIR_DIR25				(1 << LPC_GPIO_FIODIR_DIR25_bit)
#define LPC_GPIO_FIODIR_DIR26				(1 << LPC_GPIO_FIODIR_DIR26_bit)
#define LPC_GPIO_FIODIR_DIR27				(1 << LPC_GPIO_FIODIR_DIR27_bit)
#define LPC_GPIO_FIODIR_DIR28				(1 << LPC_GPIO_FIODIR_DIR28_bit)
#define LPC_GPIO_FIODIR_DIR29				(1 << LPC_GPIO_FIODIR_DIR29_bit)
#define LPC_GPIO_FIODIR_DIR30				(1 << LPC_GPIO_FIODIR_DIR30_bit)
#define LPC_GPIO_FIODIR_DIR31				(1 << LPC_GPIO_FIODIR_DIR31_bit)

#define LPC_GPIO0_FIODIR_DIR0_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR0_bit)
#define LPC_GPIO0_FIODIR_DIR1_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR1_bit)
#define LPC_GPIO0_FIODIR_DIR2_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR2_bit)
#define LPC_GPIO0_FIODIR_DIR3_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR3_bit)
#define LPC_GPIO0_FIODIR_DIR4_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR4_bit)
#define LPC_GPIO0_FIODIR_DIR5_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR5_bit)
#define LPC_GPIO0_FIODIR_DIR6_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR6_bit)
#define LPC_GPIO0_FIODIR_DIR7_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR7_bit)
#define LPC_GPIO0_FIODIR_DIR8_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR8_bit)
#define LPC_GPIO0_FIODIR_DIR9_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR9_bit)
#define LPC_GPIO0_FIODIR_DIR10_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR10_bit)
#define LPC_GPIO0_FIODIR_DIR11_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR11_bit)
#define LPC_GPIO0_FIODIR_DIR15_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR15_bit)
#define LPC_GPIO0_FIODIR_DIR16_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR16_bit)
#define LPC_GPIO0_FIODIR_DIR17_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR17_bit)
#define LPC_GPIO0_FIODIR_DIR18_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR18_bit)
#define LPC_GPIO0_FIODIR_DIR19_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR19_bit)
#define LPC_GPIO0_FIODIR_DIR20_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR20_bit)
#define LPC_GPIO0_FIODIR_DIR21_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR21_bit)
#define LPC_GPIO0_FIODIR_DIR22_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR22_bit)
#define LPC_GPIO0_FIODIR_DIR23_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR23_bit)
#define LPC_GPIO0_FIODIR_DIR24_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR24_bit)
#define LPC_GPIO0_FIODIR_DIR25_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR25_bit)
#define LPC_GPIO0_FIODIR_DIR26_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR26_bit)
#define LPC_GPIO0_FIODIR_DIR27_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR27_bit)
#define LPC_GPIO0_FIODIR_DIR28_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR28_bit)
#define LPC_GPIO0_FIODIR_DIR29_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR29_bit)
#define LPC_GPIO0_FIODIR_DIR30_bb			bitband_t BITBAND(&LPC_GPIO0->FIODIR, LPC_GPIO_FIODIR_DIR30_bit)

#define LPC_GPIO1_FIODIR_DIR0_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR0_bit)
#define LPC_GPIO1_FIODIR_DIR1_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR1_bit)
#define LPC_GPIO1_FIODIR_DIR4_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR4_bit)
#define LPC_GPIO1_FIODIR_DIR8_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR8_bit)
#define LPC_GPIO1_FIODIR_DIR9_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR9_bit)
#define LPC_GPIO1_FIODIR_DIR10_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR10_bit)
#define LPC_GPIO1_FIODIR_DIR14_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR14_bit)
#define LPC_GPIO1_FIODIR_DIR15_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR15_bit)
#define LPC_GPIO1_FIODIR_DIR16_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR16_bit)
#define LPC_GPIO1_FIODIR_DIR17_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR17_bit)
#define LPC_GPIO1_FIODIR_DIR18_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR18_bit)
#define LPC_GPIO1_FIODIR_DIR19_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR19_bit)
#define LPC_GPIO1_FIODIR_DIR20_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR20_bit)
#define LPC_GPIO1_FIODIR_DIR21_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR21_bit)
#define LPC_GPIO1_FIODIR_DIR22_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR22_bit)
#define LPC_GPIO1_FIODIR_DIR23_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR23_bit)
#define LPC_GPIO1_FIODIR_DIR24_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR24_bit)
#define LPC_GPIO1_FIODIR_DIR25_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR25_bit)
#define LPC_GPIO1_FIODIR_DIR26_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR26_bit)
#define LPC_GPIO1_FIODIR_DIR27_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR27_bit)
#define LPC_GPIO1_FIODIR_DIR28_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR28_bit)
#define LPC_GPIO1_FIODIR_DIR29_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR29_bit)
#define LPC_GPIO1_FIODIR_DIR30_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR30_bit)
#define LPC_GPIO1_FIODIR_DIR31_bb			bitband_t BITBAND(&LPC_GPIO1->FIODIR, LPC_GPIO_FIODIR_DIR31_bit)

#define LPC_GPIO2_FIODIR_DIR0_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR0_bit)
#define LPC_GPIO2_FIODIR_DIR1_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR1_bit)
#define LPC_GPIO2_FIODIR_DIR2_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR2_bit)
#define LPC_GPIO2_FIODIR_DIR3_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR3_bit)
#define LPC_GPIO2_FIODIR_DIR4_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR4_bit)
#define LPC_GPIO2_FIODIR_DIR5_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR5_bit)
#define LPC_GPIO2_FIODIR_DIR6_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR6_bit)
#define LPC_GPIO2_FIODIR_DIR7_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR7_bit)
#define LPC_GPIO2_FIODIR_DIR8_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR8_bit)
#define LPC_GPIO2_FIODIR_DIR9_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR9_bit)
#define LPC_GPIO2_FIODIR_DIR10_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR10_bit)
#define LPC_GPIO2_FIODIR_DIR11_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR11_bit)
#define LPC_GPIO2_FIODIR_DIR12_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR12_bit)
#define LPC_GPIO2_FIODIR_DIR13_bb			bitband_t BITBAND(&LPC_GPIO2->FIODIR, LPC_GPIO_FIODIR_DIR13_bit)

#define LPC_GPIO3_FIODIR_DIR25_bb			bitband_t BITBAND(&LPC_GPIO3->FIODIR, LPC_GPIO_FIODIR_DIR25_bit)
#define LPC_GPIO3_FIODIR_DIR26_bb			bitband_t BITBAND(&LPC_GPIO3->FIODIR, LPC_GPIO_FIODIR_DIR26_bit)

#define LPC_GPIO4_FIODIR_DIR28_bb			bitband_t BITBAND(&LPC_GPIO4->FIODIR, LPC_GPIO_FIODIR_DIR28_bit)
#define LPC_GPIO4_FIODIR_DIR29_bb			bitband_t BITBAND(&LPC_GPIO4->FIODIR, LPC_GPIO_FIODIR_DIR29_bit)

/*
+-----------------------------------------------------------------------------+
| FIOSET - GPIO port output Set register
+-----------------------------------------------------------------------------+
*/

#define LPC_GPIO_FIOSET_SET0_bit			0
#define LPC_GPIO_FIOSET_SET1_bit			1
#define LPC_GPIO_FIOSET_SET2_bit			2
#define LPC_GPIO_FIOSET_SET3_bit			3
#define LPC_GPIO_FIOSET_SET4_bit			4
#define LPC_GPIO_FIOSET_SET5_bit			5
#define LPC_GPIO_FIOSET_SET6_bit			6
#define LPC_GPIO_FIOSET_SET7_bit			7
#define LPC_GPIO_FIOSET_SET8_bit			8
#define LPC_GPIO_FIOSET_SET9_bit			9
#define LPC_GPIO_FIOSET_SET10_bit			10
#define LPC_GPIO_FIOSET_SET11_bit			11
#define LPC_GPIO_FIOSET_SET12_bit			12
#define LPC_GPIO_FIOSET_SET13_bit			13
#define LPC_GPIO_FIOSET_SET14_bit			14
#define LPC_GPIO_FIOSET_SET15_bit			15
#define LPC_GPIO_FIOSET_SET16_bit			16
#define LPC_GPIO_FIOSET_SET17_bit			17
#define LPC_GPIO_FIOSET_SET18_bit			18
#define LPC_GPIO_FIOSET_SET19_bit			19
#define LPC_GPIO_FIOSET_SET20_bit			20
#define LPC_GPIO_FIOSET_SET21_bit			21
#define LPC_GPIO_FIOSET_SET22_bit			22
#define LPC_GPIO_FIOSET_SET23_bit			23
#define LPC_GPIO_FIOSET_SET24_bit			24
#define LPC_GPIO_FIOSET_SET25_bit			25
#define LPC_GPIO_FIOSET_SET26_bit			26
#define LPC_GPIO_FIOSET_SET27_bit			27
#define LPC_GPIO_FIOSET_SET28_bit			28
#define LPC_GPIO_FIOSET_SET29_bit			29
#define LPC_GPIO_FIOSET_SET30_bit			30
#define LPC_GPIO_FIOSET_SET31_bit			31

#define LPC_GPIO_FIOSET_SET0				(1 << LPC_GPIO_FIOSET_SET0_bit)
#define LPC_GPIO_FIOSET_SET1				(1 << LPC_GPIO_FIOSET_SET1_bit)
#define LPC_GPIO_FIOSET_SET2				(1 << LPC_GPIO_FIOSET_SET2_bit)
#define LPC_GPIO_FIOSET_SET3				(1 << LPC_GPIO_FIOSET_SET3_bit)
#define LPC_GPIO_FIOSET_SET4				(1 << LPC_GPIO_FIOSET_SET4_bit)
#define LPC_GPIO_FIOSET_SET5				(1 << LPC_GPIO_FIOSET_SET5_bit)
#define LPC_GPIO_FIOSET_SET6				(1 << LPC_GPIO_FIOSET_SET6_bit)
#define LPC_GPIO_FIOSET_SET7				(1 << LPC_GPIO_FIOSET_SET7_bit)
#define LPC_GPIO_FIOSET_SET8				(1 << LPC_GPIO_FIOSET_SET8_bit)
#define LPC_GPIO_FIOSET_SET9				(1 << LPC_GPIO_FIOSET_SET9_bit)
#define LPC_GPIO_FIOSET_SET10				(1 << LPC_GPIO_FIOSET_SET10_bit)
#define LPC_GPIO_FIOSET_SET11				(1 << LPC_GPIO_FIOSET_SET11_bit)
#define LPC_GPIO_FIOSET_SET12				(1 << LPC_GPIO_FIOSET_SET12_bit)
#define LPC_GPIO_FIOSET_SET13				(1 << LPC_GPIO_FIOSET_SET13_bit)
#define LPC_GPIO_FIOSET_SET14				(1 << LPC_GPIO_FIOSET_SET14_bit)
#define LPC_GPIO_FIOSET_SET15				(1 << LPC_GPIO_FIOSET_SET15_bit)
#define LPC_GPIO_FIOSET_SET16				(1 << LPC_GPIO_FIOSET_SET16_bit)
#define LPC_GPIO_FIOSET_SET17				(1 << LPC_GPIO_FIOSET_SET17_bit)
#define LPC_GPIO_FIOSET_SET18				(1 << LPC_GPIO_FIOSET_SET18_bit)
#define LPC_GPIO_FIOSET_SET19				(1 << LPC_GPIO_FIOSET_SET19_bit)
#define LPC_GPIO_FIOSET_SET20				(1 << LPC_GPIO_FIOSET_SET20_bit)
#define LPC_GPIO_FIOSET_SET21				(1 << LPC_GPIO_FIOSET_SET21_bit)
#define LPC_GPIO_FIOSET_SET22				(1 << LPC_GPIO_FIOSET_SET22_bit)
#define LPC_GPIO_FIOSET_SET23				(1 << LPC_GPIO_FIOSET_SET23_bit)
#define LPC_GPIO_FIOSET_SET24				(1 << LPC_GPIO_FIOSET_SET24_bit)
#define LPC_GPIO_FIOSET_SET25				(1 << LPC_GPIO_FIOSET_SET25_bit)
#define LPC_GPIO_FIOSET_SET26				(1 << LPC_GPIO_FIOSET_SET26_bit)
#define LPC_GPIO_FIOSET_SET27				(1 << LPC_GPIO_FIOSET_SET27_bit)
#define LPC_GPIO_FIOSET_SET28				(1 << LPC_GPIO_FIOSET_SET28_bit)
#define LPC_GPIO_FIOSET_SET29				(1 << LPC_GPIO_FIOSET_SET29_bit)
#define LPC_GPIO_FIOSET_SET30				(1 << LPC_GPIO_FIOSET_SET30_bit)
#define LPC_GPIO_FIOSET_SET31				(1 << LPC_GPIO_FIOSET_SET31_bit)

#define LPC_GPIO0_FIOSET_SET0_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET0_bit)
#define LPC_GPIO0_FIOSET_SET1_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET1_bit)
#define LPC_GPIO0_FIOSET_SET2_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET2_bit)
#define LPC_GPIO0_FIOSET_SET3_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET3_bit)
#define LPC_GPIO0_FIOSET_SET4_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET4_bit)
#define LPC_GPIO0_FIOSET_SET5_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET5_bit)
#define LPC_GPIO0_FIOSET_SET6_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET6_bit)
#define LPC_GPIO0_FIOSET_SET7_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET7_bit)
#define LPC_GPIO0_FIOSET_SET8_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET8_bit)
#define LPC_GPIO0_FIOSET_SET9_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET9_bit)
#define LPC_GPIO0_FIOSET_SET10_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET10_bit)
#define LPC_GPIO0_FIOSET_SET11_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET11_bit)
#define LPC_GPIO0_FIOSET_SET15_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET15_bit)
#define LPC_GPIO0_FIOSET_SET16_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET16_bit)
#define LPC_GPIO0_FIOSET_SET17_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET17_bit)
#define LPC_GPIO0_FIOSET_SET18_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET18_bit)
#define LPC_GPIO0_FIOSET_SET19_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET19_bit)
#define LPC_GPIO0_FIOSET_SET20_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET20_bit)
#define LPC_GPIO0_FIOSET_SET21_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET21_bit)
#define LPC_GPIO0_FIOSET_SET22_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET22_bit)
#define LPC_GPIO0_FIOSET_SET23_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET23_bit)
#define LPC_GPIO0_FIOSET_SET24_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET24_bit)
#define LPC_GPIO0_FIOSET_SET25_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET25_bit)
#define LPC_GPIO0_FIOSET_SET26_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET26_bit)
#define LPC_GPIO0_FIOSET_SET27_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET27_bit)
#define LPC_GPIO0_FIOSET_SET28_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET28_bit)
#define LPC_GPIO0_FIOSET_SET29_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET29_bit)
#define LPC_GPIO0_FIOSET_SET30_bb			bitband_t BITBAND(&LPC_GPIO0->FIOSET, LPC_GPIO_FIOSET_SET30_bit)

#define LPC_GPIO1_FIOSET_SET0_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET0_bit)
#define LPC_GPIO1_FIOSET_SET1_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET1_bit)
#define LPC_GPIO1_FIOSET_SET4_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET4_bit)
#define LPC_GPIO1_FIOSET_SET8_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET8_bit)
#define LPC_GPIO1_FIOSET_SET9_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET9_bit)
#define LPC_GPIO1_FIOSET_SET10_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET10_bit)
#define LPC_GPIO1_FIOSET_SET14_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET14_bit)
#define LPC_GPIO1_FIOSET_SET15_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET15_bit)
#define LPC_GPIO1_FIOSET_SET16_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET16_bit)
#define LPC_GPIO1_FIOSET_SET17_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET17_bit)
#define LPC_GPIO1_FIOSET_SET18_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET18_bit)
#define LPC_GPIO1_FIOSET_SET19_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET19_bit)
#define LPC_GPIO1_FIOSET_SET20_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET20_bit)
#define LPC_GPIO1_FIOSET_SET21_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET21_bit)
#define LPC_GPIO1_FIOSET_SET22_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET22_bit)
#define LPC_GPIO1_FIOSET_SET23_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET23_bit)
#define LPC_GPIO1_FIOSET_SET24_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET24_bit)
#define LPC_GPIO1_FIOSET_SET25_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET25_bit)
#define LPC_GPIO1_FIOSET_SET26_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET26_bit)
#define LPC_GPIO1_FIOSET_SET27_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET27_bit)
#define LPC_GPIO1_FIOSET_SET28_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET28_bit)
#define LPC_GPIO1_FIOSET_SET29_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET29_bit)
#define LPC_GPIO1_FIOSET_SET30_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET30_bit)
#define LPC_GPIO1_FIOSET_SET31_bb			bitband_t BITBAND(&LPC_GPIO1->FIOSET, LPC_GPIO_FIOSET_SET31_bit)

#define LPC_GPIO2_FIOSET_SET0_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET0_bit)
#define LPC_GPIO2_FIOSET_SET1_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET1_bit)
#define LPC_GPIO2_FIOSET_SET2_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET2_bit)
#define LPC_GPIO2_FIOSET_SET3_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET3_bit)
#define LPC_GPIO2_FIOSET_SET4_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET4_bit)
#define LPC_GPIO2_FIOSET_SET5_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET5_bit)
#define LPC_GPIO2_FIOSET_SET6_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET6_bit)
#define LPC_GPIO2_FIOSET_SET7_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET7_bit)
#define LPC_GPIO2_FIOSET_SET8_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET8_bit)
#define LPC_GPIO2_FIOSET_SET9_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET9_bit)
#define LPC_GPIO2_FIOSET_SET10_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET10_bit)
#define LPC_GPIO2_FIOSET_SET11_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET11_bit)
#define LPC_GPIO2_FIOSET_SET12_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET12_bit)
#define LPC_GPIO2_FIOSET_SET13_bb			bitband_t BITBAND(&LPC_GPIO2->FIOSET, LPC_GPIO_FIOSET_SET13_bit)

#define LPC_GPIO3_FIOSET_SET25_bb			bitband_t BITBAND(&LPC_GPIO3->FIOSET, LPC_GPIO_FIOSET_SET25_bit)
#define LPC_GPIO3_FIOSET_SET26_bb			bitband_t BITBAND(&LPC_GPIO3->FIOSET, LPC_GPIO_FIOSET_SET26_bit)

#define LPC_GPIO4_FIOSET_SET28_bb			bitband_t BITBAND(&LPC_GPIO4->FIOSET, LPC_GPIO_FIOSET_SET28_bit)
#define LPC_GPIO4_FIOSET_SET29_bb			bitband_t BITBAND(&LPC_GPIO4->FIOSET, LPC_GPIO_FIOSET_SET29_bit)

/*
+-----------------------------------------------------------------------------+
| FIOCLR - GPIO port output Clear register
+-----------------------------------------------------------------------------+
*/

#define LPC_GPIO_FIOCLR_CLR0_bit			0
#define LPC_GPIO_FIOCLR_CLR1_bit			1
#define LPC_GPIO_FIOCLR_CLR2_bit			2
#define LPC_GPIO_FIOCLR_CLR3_bit			3
#define LPC_GPIO_FIOCLR_CLR4_bit			4
#define LPC_GPIO_FIOCLR_CLR5_bit			5
#define LPC_GPIO_FIOCLR_CLR6_bit			6
#define LPC_GPIO_FIOCLR_CLR7_bit			7
#define LPC_GPIO_FIOCLR_CLR8_bit			8
#define LPC_GPIO_FIOCLR_CLR9_bit			9
#define LPC_GPIO_FIOCLR_CLR10_bit			10
#define LPC_GPIO_FIOCLR_CLR11_bit			11
#define LPC_GPIO_FIOCLR_CLR12_bit			12
#define LPC_GPIO_FIOCLR_CLR13_bit			13
#define LPC_GPIO_FIOCLR_CLR14_bit			14
#define LPC_GPIO_FIOCLR_CLR15_bit			15
#define LPC_GPIO_FIOCLR_CLR16_bit			16
#define LPC_GPIO_FIOCLR_CLR17_bit			17
#define LPC_GPIO_FIOCLR_CLR18_bit			18
#define LPC_GPIO_FIOCLR_CLR19_bit			19
#define LPC_GPIO_FIOCLR_CLR20_bit			20
#define LPC_GPIO_FIOCLR_CLR21_bit			21
#define LPC_GPIO_FIOCLR_CLR22_bit			22
#define LPC_GPIO_FIOCLR_CLR23_bit			23
#define LPC_GPIO_FIOCLR_CLR24_bit			24
#define LPC_GPIO_FIOCLR_CLR25_bit			25
#define LPC_GPIO_FIOCLR_CLR26_bit			26
#define LPC_GPIO_FIOCLR_CLR27_bit			27
#define LPC_GPIO_FIOCLR_CLR28_bit			28
#define LPC_GPIO_FIOCLR_CLR29_bit			29
#define LPC_GPIO_FIOCLR_CLR30_bit			30
#define LPC_GPIO_FIOCLR_CLR31_bit			31

#define LPC_GPIO_FIOCLR_CLR0				(1 << LPC_GPIO_FIOCLR_CLR0_bit)
#define LPC_GPIO_FIOCLR_CLR1				(1 << LPC_GPIO_FIOCLR_CLR1_bit)
#define LPC_GPIO_FIOCLR_CLR2				(1 << LPC_GPIO_FIOCLR_CLR2_bit)
#define LPC_GPIO_FIOCLR_CLR3				(1 << LPC_GPIO_FIOCLR_CLR3_bit)
#define LPC_GPIO_FIOCLR_CLR4				(1 << LPC_GPIO_FIOCLR_CLR4_bit)
#define LPC_GPIO_FIOCLR_CLR5				(1 << LPC_GPIO_FIOCLR_CLR5_bit)
#define LPC_GPIO_FIOCLR_CLR6				(1 << LPC_GPIO_FIOCLR_CLR6_bit)
#define LPC_GPIO_FIOCLR_CLR7				(1 << LPC_GPIO_FIOCLR_CLR7_bit)
#define LPC_GPIO_FIOCLR_CLR8				(1 << LPC_GPIO_FIOCLR_CLR8_bit)
#define LPC_GPIO_FIOCLR_CLR9				(1 << LPC_GPIO_FIOCLR_CLR9_bit)
#define LPC_GPIO_FIOCLR_CLR10				(1 << LPC_GPIO_FIOCLR_CLR10_bit)
#define LPC_GPIO_FIOCLR_CLR11				(1 << LPC_GPIO_FIOCLR_CLR11_bit)
#define LPC_GPIO_FIOCLR_CLR12				(1 << LPC_GPIO_FIOCLR_CLR12_bit)
#define LPC_GPIO_FIOCLR_CLR13				(1 << LPC_GPIO_FIOCLR_CLR13_bit)
#define LPC_GPIO_FIOCLR_CLR14				(1 << LPC_GPIO_FIOCLR_CLR14_bit)
#define LPC_GPIO_FIOCLR_CLR15				(1 << LPC_GPIO_FIOCLR_CLR15_bit)
#define LPC_GPIO_FIOCLR_CLR16				(1 << LPC_GPIO_FIOCLR_CLR16_bit)
#define LPC_GPIO_FIOCLR_CLR17				(1 << LPC_GPIO_FIOCLR_CLR17_bit)
#define LPC_GPIO_FIOCLR_CLR18				(1 << LPC_GPIO_FIOCLR_CLR18_bit)
#define LPC_GPIO_FIOCLR_CLR19				(1 << LPC_GPIO_FIOCLR_CLR19_bit)
#define LPC_GPIO_FIOCLR_CLR20				(1 << LPC_GPIO_FIOCLR_CLR20_bit)
#define LPC_GPIO_FIOCLR_CLR21				(1 << LPC_GPIO_FIOCLR_CLR21_bit)
#define LPC_GPIO_FIOCLR_CLR22				(1 << LPC_GPIO_FIOCLR_CLR22_bit)
#define LPC_GPIO_FIOCLR_CLR23				(1 << LPC_GPIO_FIOCLR_CLR23_bit)
#define LPC_GPIO_FIOCLR_CLR24				(1 << LPC_GPIO_FIOCLR_CLR24_bit)
#define LPC_GPIO_FIOCLR_CLR25				(1 << LPC_GPIO_FIOCLR_CLR25_bit)
#define LPC_GPIO_FIOCLR_CLR26				(1 << LPC_GPIO_FIOCLR_CLR26_bit)
#define LPC_GPIO_FIOCLR_CLR27				(1 << LPC_GPIO_FIOCLR_CLR27_bit)
#define LPC_GPIO_FIOCLR_CLR28				(1 << LPC_GPIO_FIOCLR_CLR28_bit)
#define LPC_GPIO_FIOCLR_CLR29				(1 << LPC_GPIO_FIOCLR_CLR29_bit)
#define LPC_GPIO_FIOCLR_CLR30				(1 << LPC_GPIO_FIOCLR_CLR30_bit)
#define LPC_GPIO_FIOCLR_CLR31				(1 << LPC_GPIO_FIOCLR_CLR31_bit)

#define LPC_GPIO0_FIOCLR_CLR0_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR0_bit)
#define LPC_GPIO0_FIOCLR_CLR1_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR1_bit)
#define LPC_GPIO0_FIOCLR_CLR2_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR2_bit)
#define LPC_GPIO0_FIOCLR_CLR3_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR3_bit)
#define LPC_GPIO0_FIOCLR_CLR4_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR4_bit)
#define LPC_GPIO0_FIOCLR_CLR5_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR5_bit)
#define LPC_GPIO0_FIOCLR_CLR6_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR6_bit)
#define LPC_GPIO0_FIOCLR_CLR7_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR7_bit)
#define LPC_GPIO0_FIOCLR_CLR8_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR8_bit)
#define LPC_GPIO0_FIOCLR_CLR9_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR9_bit)
#define LPC_GPIO0_FIOCLR_CLR10_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR10_bit)
#define LPC_GPIO0_FIOCLR_CLR11_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR11_bit)
#define LPC_GPIO0_FIOCLR_CLR15_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR15_bit)
#define LPC_GPIO0_FIOCLR_CLR16_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR16_bit)
#define LPC_GPIO0_FIOCLR_CLR17_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR17_bit)
#define LPC_GPIO0_FIOCLR_CLR18_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR18_bit)
#define LPC_GPIO0_FIOCLR_CLR19_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR19_bit)
#define LPC_GPIO0_FIOCLR_CLR20_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR20_bit)
#define LPC_GPIO0_FIOCLR_CLR21_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR21_bit)
#define LPC_GPIO0_FIOCLR_CLR22_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR22_bit)
#define LPC_GPIO0_FIOCLR_CLR23_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR23_bit)
#define LPC_GPIO0_FIOCLR_CLR24_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR24_bit)
#define LPC_GPIO0_FIOCLR_CLR25_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR25_bit)
#define LPC_GPIO0_FIOCLR_CLR26_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR26_bit)
#define LPC_GPIO0_FIOCLR_CLR27_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR27_bit)
#define LPC_GPIO0_FIOCLR_CLR28_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR28_bit)
#define LPC_GPIO0_FIOCLR_CLR29_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR29_bit)
#define LPC_GPIO0_FIOCLR_CLR30_bb			bitband_t BITBAND(&LPC_GPIO0->FIOCLR, LPC_GPIO_FIOCLR_CLR30_bit)

#define LPC_GPIO1_FIOCLR_CLR0_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR0_bit)
#define LPC_GPIO1_FIOCLR_CLR1_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR1_bit)
#define LPC_GPIO1_FIOCLR_CLR4_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR4_bit)
#define LPC_GPIO1_FIOCLR_CLR8_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR8_bit)
#define LPC_GPIO1_FIOCLR_CLR9_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR9_bit)
#define LPC_GPIO1_FIOCLR_CLR10_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR10_bit)
#define LPC_GPIO1_FIOCLR_CLR14_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR14_bit)
#define LPC_GPIO1_FIOCLR_CLR15_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR15_bit)
#define LPC_GPIO1_FIOCLR_CLR16_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR16_bit)
#define LPC_GPIO1_FIOCLR_CLR17_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR17_bit)
#define LPC_GPIO1_FIOCLR_CLR18_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR18_bit)
#define LPC_GPIO1_FIOCLR_CLR19_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR19_bit)
#define LPC_GPIO1_FIOCLR_CLR20_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR20_bit)
#define LPC_GPIO1_FIOCLR_CLR21_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR21_bit)
#define LPC_GPIO1_FIOCLR_CLR22_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR22_bit)
#define LPC_GPIO1_FIOCLR_CLR23_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR23_bit)
#define LPC_GPIO1_FIOCLR_CLR24_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR24_bit)
#define LPC_GPIO1_FIOCLR_CLR25_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR25_bit)
#define LPC_GPIO1_FIOCLR_CLR26_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR26_bit)
#define LPC_GPIO1_FIOCLR_CLR27_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR27_bit)
#define LPC_GPIO1_FIOCLR_CLR28_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR28_bit)
#define LPC_GPIO1_FIOCLR_CLR29_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR29_bit)
#define LPC_GPIO1_FIOCLR_CLR30_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR30_bit)
#define LPC_GPIO1_FIOCLR_CLR31_bb			bitband_t BITBAND(&LPC_GPIO1->FIOCLR, LPC_GPIO_FIOCLR_CLR31_bit)

#define LPC_GPIO2_FIOCLR_CLR0_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR0_bit)
#define LPC_GPIO2_FIOCLR_CLR1_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR1_bit)
#define LPC_GPIO2_FIOCLR_CLR2_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR2_bit)
#define LPC_GPIO2_FIOCLR_CLR3_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR3_bit)
#define LPC_GPIO2_FIOCLR_CLR4_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR4_bit)
#define LPC_GPIO2_FIOCLR_CLR5_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR5_bit)
#define LPC_GPIO2_FIOCLR_CLR6_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR6_bit)
#define LPC_GPIO2_FIOCLR_CLR7_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR7_bit)
#define LPC_GPIO2_FIOCLR_CLR8_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR8_bit)
#define LPC_GPIO2_FIOCLR_CLR9_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR9_bit)
#define LPC_GPIO2_FIOCLR_CLR10_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR10_bit)
#define LPC_GPIO2_FIOCLR_CLR11_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR11_bit)
#define LPC_GPIO2_FIOCLR_CLR12_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR12_bit)
#define LPC_GPIO2_FIOCLR_CLR13_bb			bitband_t BITBAND(&LPC_GPIO2->FIOCLR, LPC_GPIO_FIOCLR_CLR13_bit)

#define LPC_GPIO3_FIOCLR_CLR25_bb			bitband_t BITBAND(&LPC_GPIO3->FIOCLR, LPC_GPIO_FIOCLR_CLR25_bit)
#define LPC_GPIO3_FIOCLR_CLR26_bb			bitband_t BITBAND(&LPC_GPIO3->FIOCLR, LPC_GPIO_FIOCLR_CLR26_bit)

#define LPC_GPIO4_FIOCLR_CLR28_bb			bitband_t BITBAND(&LPC_GPIO4->FIOCLR, LPC_GPIO_FIOCLR_CLR28_bit)
#define LPC_GPIO4_FIOCLR_CLR29_bb			bitband_t BITBAND(&LPC_GPIO4->FIOCLR, LPC_GPIO_FIOCLR_CLR29_bit)

/*
+-----------------------------------------------------------------------------+
| FIOPIN - GPIO port Pin value register
+-----------------------------------------------------------------------------+
*/

#define LPC_GPIO_FIOPIN_PIN0_bit			0
#define LPC_GPIO_FIOPIN_PIN1_bit			1
#define LPC_GPIO_FIOPIN_PIN2_bit			2
#define LPC_GPIO_FIOPIN_PIN3_bit			3
#define LPC_GPIO_FIOPIN_PIN4_bit			4
#define LPC_GPIO_FIOPIN_PIN5_bit			5
#define LPC_GPIO_FIOPIN_PIN6_bit			6
#define LPC_GPIO_FIOPIN_PIN7_bit			7
#define LPC_GPIO_FIOPIN_PIN8_bit			8
#define LPC_GPIO_FIOPIN_PIN9_bit			9
#define LPC_GPIO_FIOPIN_PIN10_bit			10
#define LPC_GPIO_FIOPIN_PIN11_bit			11
#define LPC_GPIO_FIOPIN_PIN12_bit			12
#define LPC_GPIO_FIOPIN_PIN13_bit			13
#define LPC_GPIO_FIOPIN_PIN14_bit			14
#define LPC_GPIO_FIOPIN_PIN15_bit			15
#define LPC_GPIO_FIOPIN_PIN16_bit			16
#define LPC_GPIO_FIOPIN_PIN17_bit			17
#define LPC_GPIO_FIOPIN_PIN18_bit			18
#define LPC_GPIO_FIOPIN_PIN19_bit			19
#define LPC_GPIO_FIOPIN_PIN20_bit			20
#define LPC_GPIO_FIOPIN_PIN21_bit			21
#define LPC_GPIO_FIOPIN_PIN22_bit			22
#define LPC_GPIO_FIOPIN_PIN23_bit			23
#define LPC_GPIO_FIOPIN_PIN24_bit			24
#define LPC_GPIO_FIOPIN_PIN25_bit			25
#define LPC_GPIO_FIOPIN_PIN26_bit			26
#define LPC_GPIO_FIOPIN_PIN27_bit			27
#define LPC_GPIO_FIOPIN_PIN28_bit			28
#define LPC_GPIO_FIOPIN_PIN29_bit			29
#define LPC_GPIO_FIOPIN_PIN30_bit			30
#define LPC_GPIO_FIOPIN_PIN31_bit			31

#define LPC_GPIO_FIOPIN_PIN0				(1 << LPC_GPIO_FIOPIN_PIN0_bit)
#define LPC_GPIO_FIOPIN_PIN1				(1 << LPC_GPIO_FIOPIN_PIN1_bit)
#define LPC_GPIO_FIOPIN_PIN2				(1 << LPC_GPIO_FIOPIN_PIN2_bit)
#define LPC_GPIO_FIOPIN_PIN3				(1 << LPC_GPIO_FIOPIN_PIN3_bit)
#define LPC_GPIO_FIOPIN_PIN4				(1 << LPC_GPIO_FIOPIN_PIN4_bit)
#define LPC_GPIO_FIOPIN_PIN5				(1 << LPC_GPIO_FIOPIN_PIN5_bit)
#define LPC_GPIO_FIOPIN_PIN6				(1 << LPC_GPIO_FIOPIN_PIN6_bit)
#define LPC_GPIO_FIOPIN_PIN7				(1 << LPC_GPIO_FIOPIN_PIN7_bit)
#define LPC_GPIO_FIOPIN_PIN8				(1 << LPC_GPIO_FIOPIN_PIN8_bit)
#define LPC_GPIO_FIOPIN_PIN9				(1 << LPC_GPIO_FIOPIN_PIN9_bit)
#define LPC_GPIO_FIOPIN_PIN10				(1 << LPC_GPIO_FIOPIN_PIN10_bit)
#define LPC_GPIO_FIOPIN_PIN11				(1 << LPC_GPIO_FIOPIN_PIN11_bit)
#define LPC_GPIO_FIOPIN_PIN12				(1 << LPC_GPIO_FIOPIN_PIN12_bit)
#define LPC_GPIO_FIOPIN_PIN13				(1 << LPC_GPIO_FIOPIN_PIN13_bit)
#define LPC_GPIO_FIOPIN_PIN14				(1 << LPC_GPIO_FIOPIN_PIN14_bit)
#define LPC_GPIO_FIOPIN_PIN15				(1 << LPC_GPIO_FIOPIN_PIN15_bit)
#define LPC_GPIO_FIOPIN_PIN16				(1 << LPC_GPIO_FIOPIN_PIN16_bit)
#define LPC_GPIO_FIOPIN_PIN17				(1 << LPC_GPIO_FIOPIN_PIN17_bit)
#define LPC_GPIO_FIOPIN_PIN18				(1 << LPC_GPIO_FIOPIN_PIN18_bit)
#define LPC_GPIO_FIOPIN_PIN19				(1 << LPC_GPIO_FIOPIN_PIN19_bit)
#define LPC_GPIO_FIOPIN_PIN20				(1 << LPC_GPIO_FIOPIN_PIN20_bit)
#define LPC_GPIO_FIOPIN_PIN21				(1 << LPC_GPIO_FIOPIN_PIN21_bit)
#define LPC_GPIO_FIOPIN_PIN22				(1 << LPC_GPIO_FIOPIN_PIN22_bit)
#define LPC_GPIO_FIOPIN_PIN23				(1 << LPC_GPIO_FIOPIN_PIN23_bit)
#define LPC_GPIO_FIOPIN_PIN24				(1 << LPC_GPIO_FIOPIN_PIN24_bit)
#define LPC_GPIO_FIOPIN_PIN25				(1 << LPC_GPIO_FIOPIN_PIN25_bit)
#define LPC_GPIO_FIOPIN_PIN26				(1 << LPC_GPIO_FIOPIN_PIN26_bit)
#define LPC_GPIO_FIOPIN_PIN27				(1 << LPC_GPIO_FIOPIN_PIN27_bit)
#define LPC_GPIO_FIOPIN_PIN28				(1 << LPC_GPIO_FIOPIN_PIN28_bit)
#define LPC_GPIO_FIOPIN_PIN29				(1 << LPC_GPIO_FIOPIN_PIN29_bit)
#define LPC_GPIO_FIOPIN_PIN30				(1 << LPC_GPIO_FIOPIN_PIN30_bit)
#define LPC_GPIO_FIOPIN_PIN31				(1 << LPC_GPIO_FIOPIN_PIN31_bit)

#define LPC_GPIO0_FIOPIN_PIN0_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN0_bit)
#define LPC_GPIO0_FIOPIN_PIN1_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN1_bit)
#define LPC_GPIO0_FIOPIN_PIN2_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN2_bit)
#define LPC_GPIO0_FIOPIN_PIN3_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN3_bit)
#define LPC_GPIO0_FIOPIN_PIN4_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN4_bit)
#define LPC_GPIO0_FIOPIN_PIN5_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN5_bit)
#define LPC_GPIO0_FIOPIN_PIN6_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN6_bit)
#define LPC_GPIO0_FIOPIN_PIN7_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN7_bit)
#define LPC_GPIO0_FIOPIN_PIN8_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN8_bit)
#define LPC_GPIO0_FIOPIN_PIN9_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN9_bit)
#define LPC_GPIO0_FIOPIN_PIN10_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN10_bit)
#define LPC_GPIO0_FIOPIN_PIN11_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN11_bit)
#define LPC_GPIO0_FIOPIN_PIN15_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN15_bit)
#define LPC_GPIO0_FIOPIN_PIN16_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN16_bit)
#define LPC_GPIO0_FIOPIN_PIN17_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN17_bit)
#define LPC_GPIO0_FIOPIN_PIN18_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN18_bit)
#define LPC_GPIO0_FIOPIN_PIN19_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN19_bit)
#define LPC_GPIO0_FIOPIN_PIN20_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN20_bit)
#define LPC_GPIO0_FIOPIN_PIN21_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN21_bit)
#define LPC_GPIO0_FIOPIN_PIN22_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN22_bit)
#define LPC_GPIO0_FIOPIN_PIN23_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN23_bit)
#define LPC_GPIO0_FIOPIN_PIN24_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN24_bit)
#define LPC_GPIO0_FIOPIN_PIN25_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN25_bit)
#define LPC_GPIO0_FIOPIN_PIN26_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN26_bit)
#define LPC_GPIO0_FIOPIN_PIN27_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN27_bit)
#define LPC_GPIO0_FIOPIN_PIN28_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN28_bit)
#define LPC_GPIO0_FIOPIN_PIN29_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN29_bit)
#define LPC_GPIO0_FIOPIN_PIN30_bb			bitband_t BITBAND(&LPC_GPIO0->FIOPIN, LPC_GPIO_FIOPIN_PIN30_bit)

#define LPC_GPIO1_FIOPIN_PIN0_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN0_bit)
#define LPC_GPIO1_FIOPIN_PIN1_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN1_bit)
#define LPC_GPIO1_FIOPIN_PIN4_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN4_bit)
#define LPC_GPIO1_FIOPIN_PIN8_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN8_bit)
#define LPC_GPIO1_FIOPIN_PIN9_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN9_bit)
#define LPC_GPIO1_FIOPIN_PIN10_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN10_bit)
#define LPC_GPIO1_FIOPIN_PIN14_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN14_bit)
#define LPC_GPIO1_FIOPIN_PIN15_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN15_bit)
#define LPC_GPIO1_FIOPIN_PIN16_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN16_bit)
#define LPC_GPIO1_FIOPIN_PIN17_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN17_bit)
#define LPC_GPIO1_FIOPIN_PIN18_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN18_bit)
#define LPC_GPIO1_FIOPIN_PIN19_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN19_bit)
#define LPC_GPIO1_FIOPIN_PIN20_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN20_bit)
#define LPC_GPIO1_FIOPIN_PIN21_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN21_bit)
#define LPC_GPIO1_FIOPIN_PIN22_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN22_bit)
#define LPC_GPIO1_FIOPIN_PIN23_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN23_bit)
#define LPC_GPIO1_FIOPIN_PIN24_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN24_bit)
#define LPC_GPIO1_FIOPIN_PIN25_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN25_bit)
#define LPC_GPIO1_FIOPIN_PIN26_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN26_bit)
#define LPC_GPIO1_FIOPIN_PIN27_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN27_bit)
#define LPC_GPIO1_FIOPIN_PIN28_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN28_bit)
#define LPC_GPIO1_FIOPIN_PIN29_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN29_bit)
#define LPC_GPIO1_FIOPIN_PIN30_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN30_bit)
#define LPC_GPIO1_FIOPIN_PIN31_bb			bitband_t BITBAND(&LPC_GPIO1->FIOPIN, LPC_GPIO_FIOPIN_PIN31_bit)

#define LPC_GPIO2_FIOPIN_PIN0_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN0_bit)
#define LPC_GPIO2_FIOPIN_PIN1_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN1_bit)
#define LPC_GPIO2_FIOPIN_PIN2_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN2_bit)
#define LPC_GPIO2_FIOPIN_PIN3_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN3_bit)
#define LPC_GPIO2_FIOPIN_PIN4_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN4_bit)
#define LPC_GPIO2_FIOPIN_PIN5_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN5_bit)
#define LPC_GPIO2_FIOPIN_PIN6_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN6_bit)
#define LPC_GPIO2_FIOPIN_PIN7_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN7_bit)
#define LPC_GPIO2_FIOPIN_PIN8_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN8_bit)
#define LPC_GPIO2_FIOPIN_PIN9_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN9_bit)
#define LPC_GPIO2_FIOPIN_PIN10_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN10_bit)
#define LPC_GPIO2_FIOPIN_PIN11_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN11_bit)
#define LPC_GPIO2_FIOPIN_PIN12_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN12_bit)
#define LPC_GPIO2_FIOPIN_PIN13_bb			bitband_t BITBAND(&LPC_GPIO2->FIOPIN, LPC_GPIO_FIOPIN_PIN13_bit)

#define LPC_GPIO3_FIOPIN_PIN25_bb			bitband_t BITBAND(&LPC_GPIO3->FIOPIN, LPC_GPIO_FIOPIN_PIN25_bit)
#define LPC_GPIO3_FIOPIN_PIN26_bb			bitband_t BITBAND(&LPC_GPIO3->FIOPIN, LPC_GPIO_FIOPIN_PIN26_bit)

#define LPC_GPIO4_FIOPIN_PIN28_bb			bitband_t BITBAND(&LPC_GPIO4->FIOPIN, LPC_GPIO_FIOPIN_PIN28_bit)
#define LPC_GPIO4_FIOPIN_PIN29_bb			bitband_t BITBAND(&LPC_GPIO4->FIOPIN, LPC_GPIO_FIOPIN_PIN29_bit)

/*
+-----------------------------------------------------------------------------+
| FIOMASK - Fast GPIO port Mask register
+-----------------------------------------------------------------------------+
*/

#define LPC_GPIO_FIOMASK_MASK0_bit			0
#define LPC_GPIO_FIOMASK_MASK1_bit			1
#define LPC_GPIO_FIOMASK_MASK2_bit			2
#define LPC_GPIO_FIOMASK_MASK3_bit			3
#define LPC_GPIO_FIOMASK_MASK4_bit			4
#define LPC_GPIO_FIOMASK_MASK5_bit			5
#define LPC_GPIO_FIOMASK_MASK6_bit			6
#define LPC_GPIO_FIOMASK_MASK7_bit			7
#define LPC_GPIO_FIOMASK_MASK8_bit			8
#define LPC_GPIO_FIOMASK_MASK9_bit			9
#define LPC_GPIO_FIOMASK_MASK10_bit			10
#define LPC_GPIO_FIOMASK_MASK11_bit			11
#define LPC_GPIO_FIOMASK_MASK12_bit			12
#define LPC_GPIO_FIOMASK_MASK13_bit			13
#define LPC_GPIO_FIOMASK_MASK14_bit			14
#define LPC_GPIO_FIOMASK_MASK15_bit			15
#define LPC_GPIO_FIOMASK_MASK16_bit			16
#define LPC_GPIO_FIOMASK_MASK17_bit			17
#define LPC_GPIO_FIOMASK_MASK18_bit			18
#define LPC_GPIO_FIOMASK_MASK19_bit			19
#define LPC_GPIO_FIOMASK_MASK20_bit			20
#define LPC_GPIO_FIOMASK_MASK21_bit			21
#define LPC_GPIO_FIOMASK_MASK22_bit			22
#define LPC_GPIO_FIOMASK_MASK23_bit			23
#define LPC_GPIO_FIOMASK_MASK24_bit			24
#define LPC_GPIO_FIOMASK_MASK25_bit			25
#define LPC_GPIO_FIOMASK_MASK26_bit			26
#define LPC_GPIO_FIOMASK_MASK27_bit			27
#define LPC_GPIO_FIOMASK_MASK28_bit			28
#define LPC_GPIO_FIOMASK_MASK29_bit			29
#define LPC_GPIO_FIOMASK_MASK30_bit			30
#define LPC_GPIO_FIOMASK_MASK31_bit			31

#define LPC_GPIO_FIOMASK_MASK0				(1 << LPC_GPIO_FIOMASK_MASK0_bit)
#define LPC_GPIO_FIOMASK_MASK1				(1 << LPC_GPIO_FIOMASK_MASK1_bit)
#define LPC_GPIO_FIOMASK_MASK2				(1 << LPC_GPIO_FIOMASK_MASK2_bit)
#define LPC_GPIO_FIOMASK_MASK3				(1 << LPC_GPIO_FIOMASK_MASK3_bit)
#define LPC_GPIO_FIOMASK_MASK4				(1 << LPC_GPIO_FIOMASK_MASK4_bit)
#define LPC_GPIO_FIOMASK_MASK5				(1 << LPC_GPIO_FIOMASK_MASK5_bit)
#define LPC_GPIO_FIOMASK_MASK6				(1 << LPC_GPIO_FIOMASK_MASK6_bit)
#define LPC_GPIO_FIOMASK_MASK7				(1 << LPC_GPIO_FIOMASK_MASK7_bit)
#define LPC_GPIO_FIOMASK_MASK8				(1 << LPC_GPIO_FIOMASK_MASK8_bit)
#define LPC_GPIO_FIOMASK_MASK9				(1 << LPC_GPIO_FIOMASK_MASK9_bit)
#define LPC_GPIO_FIOMASK_MASK10				(1 << LPC_GPIO_FIOMASK_MASK10_bit)
#define LPC_GPIO_FIOMASK_MASK11				(1 << LPC_GPIO_FIOMASK_MASK11_bit)
#define LPC_GPIO_FIOMASK_MASK12				(1 << LPC_GPIO_FIOMASK_MASK12_bit)
#define LPC_GPIO_FIOMASK_MASK13				(1 << LPC_GPIO_FIOMASK_MASK13_bit)
#define LPC_GPIO_FIOMASK_MASK14				(1 << LPC_GPIO_FIOMASK_MASK14_bit)
#define LPC_GPIO_FIOMASK_MASK15				(1 << LPC_GPIO_FIOMASK_MASK15_bit)
#define LPC_GPIO_FIOMASK_MASK16				(1 << LPC_GPIO_FIOMASK_MASK16_bit)
#define LPC_GPIO_FIOMASK_MASK17				(1 << LPC_GPIO_FIOMASK_MASK17_bit)
#define LPC_GPIO_FIOMASK_MASK18				(1 << LPC_GPIO_FIOMASK_MASK18_bit)
#define LPC_GPIO_FIOMASK_MASK19				(1 << LPC_GPIO_FIOMASK_MASK19_bit)
#define LPC_GPIO_FIOMASK_MASK20				(1 << LPC_GPIO_FIOMASK_MASK20_bit)
#define LPC_GPIO_FIOMASK_MASK21				(1 << LPC_GPIO_FIOMASK_MASK21_bit)
#define LPC_GPIO_FIOMASK_MASK22				(1 << LPC_GPIO_FIOMASK_MASK22_bit)
#define LPC_GPIO_FIOMASK_MASK23				(1 << LPC_GPIO_FIOMASK_MASK23_bit)
#define LPC_GPIO_FIOMASK_MASK24				(1 << LPC_GPIO_FIOMASK_MASK24_bit)
#define LPC_GPIO_FIOMASK_MASK25				(1 << LPC_GPIO_FIOMASK_MASK25_bit)
#define LPC_GPIO_FIOMASK_MASK26				(1 << LPC_GPIO_FIOMASK_MASK26_bit)
#define LPC_GPIO_FIOMASK_MASK27				(1 << LPC_GPIO_FIOMASK_MASK27_bit)
#define LPC_GPIO_FIOMASK_MASK28				(1 << LPC_GPIO_FIOMASK_MASK28_bit)
#define LPC_GPIO_FIOMASK_MASK29				(1 << LPC_GPIO_FIOMASK_MASK29_bit)
#define LPC_GPIO_FIOMASK_MASK30				(1 << LPC_GPIO_FIOMASK_MASK30_bit)
#define LPC_GPIO_FIOMASK_MASK31				(1 << LPC_GPIO_FIOMASK_MASK31_bit)

#define LPC_GPIO0_FIOMASK_MASK0_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK0_bit)
#define LPC_GPIO0_FIOMASK_MASK1_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK1_bit)
#define LPC_GPIO0_FIOMASK_MASK2_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK2_bit)
#define LPC_GPIO0_FIOMASK_MASK3_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK3_bit)
#define LPC_GPIO0_FIOMASK_MASK4_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK4_bit)
#define LPC_GPIO0_FIOMASK_MASK5_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK5_bit)
#define LPC_GPIO0_FIOMASK_MASK6_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK6_bit)
#define LPC_GPIO0_FIOMASK_MASK7_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK7_bit)
#define LPC_GPIO0_FIOMASK_MASK8_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK8_bit)
#define LPC_GPIO0_FIOMASK_MASK9_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK9_bit)
#define LPC_GPIO0_FIOMASK_MASK10_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK10_bit)
#define LPC_GPIO0_FIOMASK_MASK11_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK11_bit)
#define LPC_GPIO0_FIOMASK_MASK15_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK15_bit)
#define LPC_GPIO0_FIOMASK_MASK16_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK16_bit)
#define LPC_GPIO0_FIOMASK_MASK17_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK17_bit)
#define LPC_GPIO0_FIOMASK_MASK18_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK18_bit)
#define LPC_GPIO0_FIOMASK_MASK19_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK19_bit)
#define LPC_GPIO0_FIOMASK_MASK20_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK20_bit)
#define LPC_GPIO0_FIOMASK_MASK21_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK21_bit)
#define LPC_GPIO0_FIOMASK_MASK22_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK22_bit)
#define LPC_GPIO0_FIOMASK_MASK23_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK23_bit)
#define LPC_GPIO0_FIOMASK_MASK24_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK24_bit)
#define LPC_GPIO0_FIOMASK_MASK25_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK25_bit)
#define LPC_GPIO0_FIOMASK_MASK26_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK26_bit)
#define LPC_GPIO0_FIOMASK_MASK27_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK27_bit)
#define LPC_GPIO0_FIOMASK_MASK28_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK28_bit)
#define LPC_GPIO0_FIOMASK_MASK29_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK29_bit)
#define LPC_GPIO0_FIOMASK_MASK30_bb			bitband_t BITBAND(&LPC_GPIO0->FIOMASK, LPC_GPIO_FIOMASK_MASK30_bit)

#define LPC_GPIO1_FIOMASK_MASK0_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK0_bit)
#define LPC_GPIO1_FIOMASK_MASK1_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK1_bit)
#define LPC_GPIO1_FIOMASK_MASK4_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK4_bit)
#define LPC_GPIO1_FIOMASK_MASK8_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK8_bit)
#define LPC_GPIO1_FIOMASK_MASK9_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK9_bit)
#define LPC_GPIO1_FIOMASK_MASK10_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK10_bit)
#define LPC_GPIO1_FIOMASK_MASK14_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK14_bit)
#define LPC_GPIO1_FIOMASK_MASK15_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK15_bit)
#define LPC_GPIO1_FIOMASK_MASK16_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK16_bit)
#define LPC_GPIO1_FIOMASK_MASK17_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK17_bit)
#define LPC_GPIO1_FIOMASK_MASK18_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK18_bit)
#define LPC_GPIO1_FIOMASK_MASK19_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK19_bit)
#define LPC_GPIO1_FIOMASK_MASK20_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK20_bit)
#define LPC_GPIO1_FIOMASK_MASK21_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK21_bit)
#define LPC_GPIO1_FIOMASK_MASK22_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK22_bit)
#define LPC_GPIO1_FIOMASK_MASK23_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK23_bit)
#define LPC_GPIO1_FIOMASK_MASK24_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK24_bit)
#define LPC_GPIO1_FIOMASK_MASK25_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK25_bit)
#define LPC_GPIO1_FIOMASK_MASK26_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK26_bit)
#define LPC_GPIO1_FIOMASK_MASK27_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK27_bit)
#define LPC_GPIO1_FIOMASK_MASK28_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK28_bit)
#define LPC_GPIO1_FIOMASK_MASK29_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK29_bit)
#define LPC_GPIO1_FIOMASK_MASK30_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK30_bit)
#define LPC_GPIO1_FIOMASK_MASK31_bb			bitband_t BITBAND(&LPC_GPIO1->FIOMASK, LPC_GPIO_FIOMASK_MASK31_bit)

#define LPC_GPIO2_FIOMASK_MASK0_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK0_bit)
#define LPC_GPIO2_FIOMASK_MASK1_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK1_bit)
#define LPC_GPIO2_FIOMASK_MASK2_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK2_bit)
#define LPC_GPIO2_FIOMASK_MASK3_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK3_bit)
#define LPC_GPIO2_FIOMASK_MASK4_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK4_bit)
#define LPC_GPIO2_FIOMASK_MASK5_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK5_bit)
#define LPC_GPIO2_FIOMASK_MASK6_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK6_bit)
#define LPC_GPIO2_FIOMASK_MASK7_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK7_bit)
#define LPC_GPIO2_FIOMASK_MASK8_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK8_bit)
#define LPC_GPIO2_FIOMASK_MASK9_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK9_bit)
#define LPC_GPIO2_FIOMASK_MASK10_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK10_bit)
#define LPC_GPIO2_FIOMASK_MASK11_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK11_bit)
#define LPC_GPIO2_FIOMASK_MASK12_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK12_bit)
#define LPC_GPIO2_FIOMASK_MASK13_bb			bitband_t BITBAND(&LPC_GPIO2->FIOMASK, LPC_GPIO_FIOMASK_MASK13_bit)

#define LPC_GPIO3_FIOMASK_MASK25_bb			bitband_t BITBAND(&LPC_GPIO3->FIOMASK, LPC_GPIO_FIOMASK_MASK25_bit)
#define LPC_GPIO3_FIOMASK_MASK26_bb			bitband_t BITBAND(&LPC_GPIO3->FIOMASK, LPC_GPIO_FIOMASK_MASK26_bit)

#define LPC_GPIO4_FIOMASK_MASK28_bb			bitband_t BITBAND(&LPC_GPIO4->FIOMASK, LPC_GPIO_FIOMASK_MASK28_bit)
#define LPC_GPIO4_FIOMASK_MASK29_bb			bitband_t BITBAND(&LPC_GPIO4->FIOMASK, LPC_GPIO_FIOMASK_MASK29_bit)

/******************************************************************************
* END OF FILE
******************************************************************************/
#endif /* HDR_GPIO_H_ */
