/** \file hdr_pincon.h
 * \brief Header with definition of bits in Pin Connect Block registers
 * \author Freddie Chopin, http://www.freddiechopin.info/
 * \date 2012-04-07
 */

/******************************************************************************
* chip: LPC175x / LPC176x
* compiler: arm-none-eabi-gcc (GNU Tools for ARM Embedded Processors) 4.6.2
* 	20110921 (release) [ARM/embedded-4_6-branch revision 182083]
******************************************************************************/

#ifndef HDR_PINCON_H_
#define HDR_PINCON_H_

#include "hdr/hdr_bitband.h"

/*
+=============================================================================+
| global definitions
+=============================================================================+
*/

#define LPC_PINCON_PINSELx_DEFAULT_value		0
#define LPC_PINCON_PINSELx_ALT1_value			1
#define LPC_PINCON_PINSELx_ALT2_value			2
#define LPC_PINCON_PINSELx_ALT3_value			3
#define LPC_PINCON_PINSELx_mask					3

#define LPC_PINCON_PINMODEx_PULL_UP_value		0
#define LPC_PINCON_PINMODEx_REPEATER_value		1
#define LPC_PINCON_PINMODEx_FLOATING_value		2
#define LPC_PINCON_PINMODEx_PULL_DOWN_value		3
#define LPC_PINCON_PINMODEx_mask				3

#define LPC_PINCON_PINMODE_ODx_PP_value			0
#define LPC_PINCON_PINMODE_ODx_OD_value			1
#define LPC_PINCON_PINMODE_ODx_mask				1

/*
+-----------------------------------------------------------------------------+
| PINSEL0 - Pin function select register 0
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINSEL0_P0_0SEL_bit			0
#define LPC_PINCON_PINSEL0_P0_0SEL_0_bit		0
#define LPC_PINCON_PINSEL0_P0_0SEL_1_bit		1
#define LPC_PINCON_PINSEL0_P0_1SEL_bit			2
#define LPC_PINCON_PINSEL0_P0_1SEL_0_bit		2
#define LPC_PINCON_PINSEL0_P0_1SEL_1_bit		3
#define LPC_PINCON_PINSEL0_P0_2SEL_bit			4
#define LPC_PINCON_PINSEL0_P0_2SEL_0_bit		4
#define LPC_PINCON_PINSEL0_P0_2SEL_1_bit		5
#define LPC_PINCON_PINSEL0_P0_3SEL_bit			6
#define LPC_PINCON_PINSEL0_P0_3SEL_0_bit		6
#define LPC_PINCON_PINSEL0_P0_3SEL_1_bit		7
#define LPC_PINCON_PINSEL0_P0_4SEL_bit			8
#define LPC_PINCON_PINSEL0_P0_4SEL_0_bit		8
#define LPC_PINCON_PINSEL0_P0_4SEL_1_bit		9
#define LPC_PINCON_PINSEL0_P0_5SEL_bit			10
#define LPC_PINCON_PINSEL0_P0_5SEL_0_bit		10
#define LPC_PINCON_PINSEL0_P0_5SEL_1_bit		11
#define LPC_PINCON_PINSEL0_P0_6SEL_bit			12
#define LPC_PINCON_PINSEL0_P0_6SEL_0_bit		12
#define LPC_PINCON_PINSEL0_P0_6SEL_1_bit		13
#define LPC_PINCON_PINSEL0_P0_7SEL_bit			14
#define LPC_PINCON_PINSEL0_P0_7SEL_0_bit		14
#define LPC_PINCON_PINSEL0_P0_7SEL_1_bit		15
#define LPC_PINCON_PINSEL0_P0_8SEL_bit			16
#define LPC_PINCON_PINSEL0_P0_8SEL_0_bit		16
#define LPC_PINCON_PINSEL0_P0_8SEL_1_bit		17
#define LPC_PINCON_PINSEL0_P0_9SEL_bit			18
#define LPC_PINCON_PINSEL0_P0_9SEL_0_bit		18
#define LPC_PINCON_PINSEL0_P0_9SEL_1_bit		19
#define LPC_PINCON_PINSEL0_P0_10SEL_bit			20
#define LPC_PINCON_PINSEL0_P0_10SEL_0_bit		20
#define LPC_PINCON_PINSEL0_P0_10SEL_1_bit		21
#define LPC_PINCON_PINSEL0_P0_11SEL_bit			22
#define LPC_PINCON_PINSEL0_P0_11SEL_0_bit		22
#define LPC_PINCON_PINSEL0_P0_11SEL_1_bit		23
#define LPC_PINCON_PINSEL0_P0_15SEL_bit			30
#define LPC_PINCON_PINSEL0_P0_15SEL_0_bit		30
#define LPC_PINCON_PINSEL0_P0_15SEL_1_bit		31

#define LPC_PINCON_PINSEL0_P0_0SEL_0			(1 << LPC_PINCON_PINSEL0_P0_0SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_0SEL_1			(1 << LPC_PINCON_PINSEL0_P0_0SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_1SEL_0			(1 << LPC_PINCON_PINSEL0_P0_1SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_1SEL_1			(1 << LPC_PINCON_PINSEL0_P0_1SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_2SEL_0			(1 << LPC_PINCON_PINSEL0_P0_2SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_2SEL_1			(1 << LPC_PINCON_PINSEL0_P0_2SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_3SEL_0			(1 << LPC_PINCON_PINSEL0_P0_3SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_3SEL_1			(1 << LPC_PINCON_PINSEL0_P0_3SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_4SEL_0			(1 << LPC_PINCON_PINSEL0_P0_4SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_4SEL_1			(1 << LPC_PINCON_PINSEL0_P0_4SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_5SEL_0			(1 << LPC_PINCON_PINSEL0_P0_5SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_5SEL_1			(1 << LPC_PINCON_PINSEL0_P0_5SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_6SEL_0			(1 << LPC_PINCON_PINSEL0_P0_6SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_6SEL_1			(1 << LPC_PINCON_PINSEL0_P0_6SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_7SEL_0			(1 << LPC_PINCON_PINSEL0_P0_7SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_7SEL_1			(1 << LPC_PINCON_PINSEL0_P0_7SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_8SEL_0			(1 << LPC_PINCON_PINSEL0_P0_8SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_8SEL_1			(1 << LPC_PINCON_PINSEL0_P0_8SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_9SEL_0			(1 << LPC_PINCON_PINSEL0_P0_9SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_9SEL_1			(1 << LPC_PINCON_PINSEL0_P0_9SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_10SEL_0			(1 << LPC_PINCON_PINSEL0_P0_10SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_10SEL_1			(1 << LPC_PINCON_PINSEL0_P0_10SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_11SEL_0			(1 << LPC_PINCON_PINSEL0_P0_11SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_11SEL_1			(1 << LPC_PINCON_PINSEL0_P0_11SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_15SEL_0			(1 << LPC_PINCON_PINSEL0_P0_15SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_15SEL_1			(1 << LPC_PINCON_PINSEL0_P0_15SEL_1_bit)

#define LPC_PINCON_PINSEL0_P0_0SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_0SEL_bit)
#define LPC_PINCON_PINSEL0_P0_0SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_0SEL_bit)
#define LPC_PINCON_PINSEL0_P0_0SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_0SEL_bit)
#define LPC_PINCON_PINSEL0_P0_0SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_0SEL_bit)

#define LPC_PINCON_PINSEL0_P0_1SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_1SEL_bit)
#define LPC_PINCON_PINSEL0_P0_1SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_1SEL_bit)
#define LPC_PINCON_PINSEL0_P0_1SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_1SEL_bit)
#define LPC_PINCON_PINSEL0_P0_1SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_1SEL_bit)

#define LPC_PINCON_PINSEL0_P0_2SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_2SEL_bit)
#define LPC_PINCON_PINSEL0_P0_2SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_2SEL_bit)
#define LPC_PINCON_PINSEL0_P0_2SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_2SEL_bit)

#define LPC_PINCON_PINSEL0_P0_3SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_3SEL_bit)
#define LPC_PINCON_PINSEL0_P0_3SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_3SEL_bit)
#define LPC_PINCON_PINSEL0_P0_3SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_3SEL_bit)

#define LPC_PINCON_PINSEL0_P0_4SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_4SEL_bit)
#define LPC_PINCON_PINSEL0_P0_4SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_4SEL_bit)
#define LPC_PINCON_PINSEL0_P0_4SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_4SEL_bit)
#define LPC_PINCON_PINSEL0_P0_4SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_4SEL_bit)

#define LPC_PINCON_PINSEL0_P0_5SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_5SEL_bit)
#define LPC_PINCON_PINSEL0_P0_5SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_5SEL_bit)
#define LPC_PINCON_PINSEL0_P0_5SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_5SEL_bit)
#define LPC_PINCON_PINSEL0_P0_5SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_5SEL_bit)

#define LPC_PINCON_PINSEL0_P0_6SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_6SEL_bit)
#define LPC_PINCON_PINSEL0_P0_6SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_6SEL_bit)
#define LPC_PINCON_PINSEL0_P0_6SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_6SEL_bit)
#define LPC_PINCON_PINSEL0_P0_6SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_6SEL_bit)

#define LPC_PINCON_PINSEL0_P0_7SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_7SEL_bit)
#define LPC_PINCON_PINSEL0_P0_7SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_7SEL_bit)
#define LPC_PINCON_PINSEL0_P0_7SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_7SEL_bit)
#define LPC_PINCON_PINSEL0_P0_7SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_7SEL_bit)

#define LPC_PINCON_PINSEL0_P0_8SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_8SEL_bit)
#define LPC_PINCON_PINSEL0_P0_8SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_8SEL_bit)
#define LPC_PINCON_PINSEL0_P0_8SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_8SEL_bit)
#define LPC_PINCON_PINSEL0_P0_8SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_8SEL_bit)

#define LPC_PINCON_PINSEL0_P0_9SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_9SEL_bit)
#define LPC_PINCON_PINSEL0_P0_9SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_9SEL_bit)
#define LPC_PINCON_PINSEL0_P0_9SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_9SEL_bit)
#define LPC_PINCON_PINSEL0_P0_9SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_9SEL_bit)

#define LPC_PINCON_PINSEL0_P0_10SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_10SEL_bit)
#define LPC_PINCON_PINSEL0_P0_10SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_10SEL_bit)
#define LPC_PINCON_PINSEL0_P0_10SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_10SEL_bit)
#define LPC_PINCON_PINSEL0_P0_10SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_10SEL_bit)

#define LPC_PINCON_PINSEL0_P0_11SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_11SEL_bit)
#define LPC_PINCON_PINSEL0_P0_11SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_11SEL_bit)
#define LPC_PINCON_PINSEL0_P0_11SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_11SEL_bit)
#define LPC_PINCON_PINSEL0_P0_11SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_11SEL_bit)

#define LPC_PINCON_PINSEL0_P0_15SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL0_P0_15SEL_bit)
#define LPC_PINCON_PINSEL0_P0_15SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL0_P0_15SEL_bit)
#define LPC_PINCON_PINSEL0_P0_15SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL0_P0_15SEL_bit)
#define LPC_PINCON_PINSEL0_P0_15SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL0_P0_15SEL_bit)

#define LPC_PINCON_PINSEL0_P0_0SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_0SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_0SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_0SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_1SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_1SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_1SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_1SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_2SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_2SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_2SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_2SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_3SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_3SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_3SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_3SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_4SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_4SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_4SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_4SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_5SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_5SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_5SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_5SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_6SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_6SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_6SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_6SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_7SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_7SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_7SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_7SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_8SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_8SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_8SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_8SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_9SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_9SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_9SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_9SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_10SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_10SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_10SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_10SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_11SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_11SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_11SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_11SEL_1_bit)
#define LPC_PINCON_PINSEL0_P0_15SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_15SEL_0_bit)
#define LPC_PINCON_PINSEL0_P0_15SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL0, LPC_PINCON_PINSEL0_P0_15SEL_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINSEL1 - Pin function select register 1
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINSEL1_P0_16SEL_bit			0
#define LPC_PINCON_PINSEL1_P0_16SEL_0_bit		0
#define LPC_PINCON_PINSEL1_P0_16SEL_1_bit		1
#define LPC_PINCON_PINSEL1_P0_17SEL_bit			2
#define LPC_PINCON_PINSEL1_P0_17SEL_0_bit		2
#define LPC_PINCON_PINSEL1_P0_17SEL_1_bit		3
#define LPC_PINCON_PINSEL1_P0_18SEL_bit			4
#define LPC_PINCON_PINSEL1_P0_18SEL_0_bit		4
#define LPC_PINCON_PINSEL1_P0_18SEL_1_bit		5
#define LPC_PINCON_PINSEL1_P0_19SEL_bit			6
#define LPC_PINCON_PINSEL1_P0_19SEL_0_bit		6
#define LPC_PINCON_PINSEL1_P0_19SEL_1_bit		7
#define LPC_PINCON_PINSEL1_P0_20SEL_bit			8
#define LPC_PINCON_PINSEL1_P0_20SEL_0_bit		8
#define LPC_PINCON_PINSEL1_P0_20SEL_1_bit		9
#define LPC_PINCON_PINSEL1_P0_21SEL_bit			10
#define LPC_PINCON_PINSEL1_P0_21SEL_0_bit		10
#define LPC_PINCON_PINSEL1_P0_21SEL_1_bit		11
#define LPC_PINCON_PINSEL1_P0_22SEL_bit			12
#define LPC_PINCON_PINSEL1_P0_22SEL_0_bit		12
#define LPC_PINCON_PINSEL1_P0_22SEL_1_bit		13
#define LPC_PINCON_PINSEL1_P0_23SEL_bit			14
#define LPC_PINCON_PINSEL1_P0_23SEL_0_bit		14
#define LPC_PINCON_PINSEL1_P0_23SEL_1_bit		15
#define LPC_PINCON_PINSEL1_P0_24SEL_bit			16
#define LPC_PINCON_PINSEL1_P0_24SEL_0_bit		16
#define LPC_PINCON_PINSEL1_P0_24SEL_1_bit		17
#define LPC_PINCON_PINSEL1_P0_25SEL_bit			18
#define LPC_PINCON_PINSEL1_P0_25SEL_0_bit		18
#define LPC_PINCON_PINSEL1_P0_25SEL_1_bit		19
#define LPC_PINCON_PINSEL1_P0_26SEL_bit			20
#define LPC_PINCON_PINSEL1_P0_26SEL_0_bit		20
#define LPC_PINCON_PINSEL1_P0_26SEL_1_bit		21
#define LPC_PINCON_PINSEL1_P0_27SEL_bit			22
#define LPC_PINCON_PINSEL1_P0_27SEL_0_bit		22
#define LPC_PINCON_PINSEL1_P0_27SEL_1_bit		23
#define LPC_PINCON_PINSEL1_P0_28SEL_bit			24
#define LPC_PINCON_PINSEL1_P0_28SEL_0_bit		24
#define LPC_PINCON_PINSEL1_P0_28SEL_1_bit		25
#define LPC_PINCON_PINSEL1_P0_29SEL_bit			26
#define LPC_PINCON_PINSEL1_P0_29SEL_0_bit		26
#define LPC_PINCON_PINSEL1_P0_29SEL_1_bit		27
#define LPC_PINCON_PINSEL1_P0_30SEL_bit			28
#define LPC_PINCON_PINSEL1_P0_30SEL_0_bit		28
#define LPC_PINCON_PINSEL1_P0_30SEL_1_bit		29

#define LPC_PINCON_PINSEL1_P0_16SEL_0			(1 << LPC_PINCON_PINSEL1_P0_16SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_16SEL_1			(1 << LPC_PINCON_PINSEL1_P0_16SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_17SEL_0			(1 << LPC_PINCON_PINSEL1_P0_17SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_17SEL_1			(1 << LPC_PINCON_PINSEL1_P0_17SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_18SEL_0			(1 << LPC_PINCON_PINSEL1_P0_18SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_18SEL_1			(1 << LPC_PINCON_PINSEL1_P0_18SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_19SEL_0			(1 << LPC_PINCON_PINSEL1_P0_19SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_19SEL_1			(1 << LPC_PINCON_PINSEL1_P0_19SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_20SEL_0			(1 << LPC_PINCON_PINSEL1_P0_20SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_20SEL_1			(1 << LPC_PINCON_PINSEL1_P0_20SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_21SEL_0			(1 << LPC_PINCON_PINSEL1_P0_21SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_21SEL_1			(1 << LPC_PINCON_PINSEL1_P0_21SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_22SEL_0			(1 << LPC_PINCON_PINSEL1_P0_22SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_22SEL_1			(1 << LPC_PINCON_PINSEL1_P0_22SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_23SEL_0			(1 << LPC_PINCON_PINSEL1_P0_23SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_23SEL_1			(1 << LPC_PINCON_PINSEL1_P0_23SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_24SEL_0			(1 << LPC_PINCON_PINSEL1_P0_24SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_24SEL_1			(1 << LPC_PINCON_PINSEL1_P0_24SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_25SEL_0			(1 << LPC_PINCON_PINSEL1_P0_25SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_25SEL_1			(1 << LPC_PINCON_PINSEL1_P0_25SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_26SEL_0			(1 << LPC_PINCON_PINSEL1_P0_26SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_26SEL_1			(1 << LPC_PINCON_PINSEL1_P0_26SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_27SEL_0			(1 << LPC_PINCON_PINSEL1_P0_27SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_27SEL_1			(1 << LPC_PINCON_PINSEL1_P0_27SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_28SEL_0			(1 << LPC_PINCON_PINSEL1_P0_28SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_28SEL_1			(1 << LPC_PINCON_PINSEL1_P0_28SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_29SEL_0			(1 << LPC_PINCON_PINSEL1_P0_29SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_29SEL_1			(1 << LPC_PINCON_PINSEL1_P0_29SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_30SEL_0			(1 << LPC_PINCON_PINSEL1_P0_30SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_30SEL_1			(1 << LPC_PINCON_PINSEL1_P0_30SEL_1_bit)

#define LPC_PINCON_PINSEL1_P0_16SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_16SEL_bit)
#define LPC_PINCON_PINSEL1_P0_16SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_16SEL_bit)
#define LPC_PINCON_PINSEL1_P0_16SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_16SEL_bit)
#define LPC_PINCON_PINSEL1_P0_16SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_16SEL_bit)

#define LPC_PINCON_PINSEL1_P0_17SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_17SEL_bit)
#define LPC_PINCON_PINSEL1_P0_17SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_17SEL_bit)
#define LPC_PINCON_PINSEL1_P0_17SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_17SEL_bit)
#define LPC_PINCON_PINSEL1_P0_17SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_17SEL_bit)

#define LPC_PINCON_PINSEL1_P0_18SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_18SEL_bit)
#define LPC_PINCON_PINSEL1_P0_18SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_18SEL_bit)
#define LPC_PINCON_PINSEL1_P0_18SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_18SEL_bit)
#define LPC_PINCON_PINSEL1_P0_18SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_18SEL_bit)

#define LPC_PINCON_PINSEL1_P0_19SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_19SEL_bit)
#define LPC_PINCON_PINSEL1_P0_19SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_19SEL_bit)
#define LPC_PINCON_PINSEL1_P0_19SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_19SEL_bit)

#define LPC_PINCON_PINSEL1_P0_20SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_20SEL_bit)
#define LPC_PINCON_PINSEL1_P0_20SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_20SEL_bit)
#define LPC_PINCON_PINSEL1_P0_20SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_20SEL_bit)

#define LPC_PINCON_PINSEL1_P0_21SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_21SEL_bit)
#define LPC_PINCON_PINSEL1_P0_21SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_21SEL_bit)
#define LPC_PINCON_PINSEL1_P0_21SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_21SEL_bit)

#define LPC_PINCON_PINSEL1_P0_22SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_22SEL_bit)
#define LPC_PINCON_PINSEL1_P0_22SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_22SEL_bit)
#define LPC_PINCON_PINSEL1_P0_22SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_22SEL_bit)

#define LPC_PINCON_PINSEL1_P0_23SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_23SEL_bit)
#define LPC_PINCON_PINSEL1_P0_23SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_23SEL_bit)
#define LPC_PINCON_PINSEL1_P0_23SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_23SEL_bit)
#define LPC_PINCON_PINSEL1_P0_23SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_23SEL_bit)

#define LPC_PINCON_PINSEL1_P0_24SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_24SEL_bit)
#define LPC_PINCON_PINSEL1_P0_24SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_24SEL_bit)
#define LPC_PINCON_PINSEL1_P0_24SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_24SEL_bit)
#define LPC_PINCON_PINSEL1_P0_24SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_24SEL_bit)

#define LPC_PINCON_PINSEL1_P0_25SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_25SEL_bit)
#define LPC_PINCON_PINSEL1_P0_25SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_25SEL_bit)
#define LPC_PINCON_PINSEL1_P0_25SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_25SEL_bit)
#define LPC_PINCON_PINSEL1_P0_25SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_25SEL_bit)

#define LPC_PINCON_PINSEL1_P0_26SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_26SEL_bit)
#define LPC_PINCON_PINSEL1_P0_26SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_26SEL_bit)
#define LPC_PINCON_PINSEL1_P0_26SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_26SEL_bit)
#define LPC_PINCON_PINSEL1_P0_26SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL1_P0_26SEL_bit)

#define LPC_PINCON_PINSEL1_P0_27SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_27SEL_bit)
#define LPC_PINCON_PINSEL1_P0_27SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_27SEL_bit)
#define LPC_PINCON_PINSEL1_P0_27SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_27SEL_bit)

#define LPC_PINCON_PINSEL1_P0_28SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_28SEL_bit)
#define LPC_PINCON_PINSEL1_P0_28SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_28SEL_bit)
#define LPC_PINCON_PINSEL1_P0_28SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL1_P0_28SEL_bit)

#define LPC_PINCON_PINSEL1_P0_29SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_29SEL_bit)
#define LPC_PINCON_PINSEL1_P0_29SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_29SEL_bit)

#define LPC_PINCON_PINSEL1_P0_30SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL1_P0_30SEL_bit)
#define LPC_PINCON_PINSEL1_P0_30SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL1_P0_30SEL_bit)

#define LPC_PINCON_PINSEL1_P0_16SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_16SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_16SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_16SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_17SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_17SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_17SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_17SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_18SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_18SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_18SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_18SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_19SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_19SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_19SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_19SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_20SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_20SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_20SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_20SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_21SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_21SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_21SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_21SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_22SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_22SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_22SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_22SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_23SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_23SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_23SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_23SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_24SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_24SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_24SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_24SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_25SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_25SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_25SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_25SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_26SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_26SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_26SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_26SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_27SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_27SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_27SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_27SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_28SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_28SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_28SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_28SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_29SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_29SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_29SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_29SEL_1_bit)
#define LPC_PINCON_PINSEL1_P0_30SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_30SEL_0_bit)
#define LPC_PINCON_PINSEL1_P0_30SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL1, LPC_PINCON_PINSEL1_P0_30SEL_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINSEL2 - Pin function select register 2
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINSEL2_P1_0SEL_bit			0
#define LPC_PINCON_PINSEL2_P1_0SEL_0_bit		0
#define LPC_PINCON_PINSEL2_P1_0SEL_1_bit		1
#define LPC_PINCON_PINSEL2_P1_1SEL_bit			2
#define LPC_PINCON_PINSEL2_P1_1SEL_0_bit		2
#define LPC_PINCON_PINSEL2_P1_1SEL_1_bit		3
#define LPC_PINCON_PINSEL2_P1_4SEL_bit			8
#define LPC_PINCON_PINSEL2_P1_4SEL_0_bit		8
#define LPC_PINCON_PINSEL2_P1_4SEL_1_bit		9
#define LPC_PINCON_PINSEL2_P1_8SEL_bit			16
#define LPC_PINCON_PINSEL2_P1_8SEL_0_bit		16
#define LPC_PINCON_PINSEL2_P1_8SEL_1_bit		17
#define LPC_PINCON_PINSEL2_P1_9SEL_bit			18
#define LPC_PINCON_PINSEL2_P1_9SEL_0_bit		18
#define LPC_PINCON_PINSEL2_P1_9SEL_1_bit		19
#define LPC_PINCON_PINSEL2_P1_10SEL_bit			20
#define LPC_PINCON_PINSEL2_P1_10SEL_0_bit		20
#define LPC_PINCON_PINSEL2_P1_10SEL_1_bit		21
#define LPC_PINCON_PINSEL2_P1_14SEL_bit			28
#define LPC_PINCON_PINSEL2_P1_14SEL_0_bit		28
#define LPC_PINCON_PINSEL2_P1_14SEL_1_bit		29
#define LPC_PINCON_PINSEL2_P1_15SEL_bit			30
#define LPC_PINCON_PINSEL2_P1_15SEL_0_bit		30
#define LPC_PINCON_PINSEL2_P1_15SEL_1_bit		31

#define LPC_PINCON_PINSEL2_P1_0SEL_0			(1 << LPC_PINCON_PINSEL2_P1_0SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_0SEL_1			(1 << LPC_PINCON_PINSEL2_P1_0SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_1SEL_0			(1 << LPC_PINCON_PINSEL2_P1_1SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_1SEL_1			(1 << LPC_PINCON_PINSEL2_P1_1SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_4SEL_0			(1 << LPC_PINCON_PINSEL2_P1_4SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_4SEL_1			(1 << LPC_PINCON_PINSEL2_P1_4SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_8SEL_0			(1 << LPC_PINCON_PINSEL2_P1_8SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_8SEL_1			(1 << LPC_PINCON_PINSEL2_P1_8SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_9SEL_0			(1 << LPC_PINCON_PINSEL2_P1_9SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_9SEL_1			(1 << LPC_PINCON_PINSEL2_P1_9SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_10SEL_0			(1 << LPC_PINCON_PINSEL2_P1_10SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_10SEL_1			(1 << LPC_PINCON_PINSEL2_P1_10SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_14SEL_0			(1 << LPC_PINCON_PINSEL2_P1_14SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_14SEL_1			(1 << LPC_PINCON_PINSEL2_P1_14SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_15SEL_0			(1 << LPC_PINCON_PINSEL2_P1_15SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_15SEL_1			(1 << LPC_PINCON_PINSEL2_P1_15SEL_1_bit)

#define LPC_PINCON_PINSEL2_P1_0SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL2_P1_0SEL_bit)
#define LPC_PINCON_PINSEL2_P1_0SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL2_P1_0SEL_bit)

#define LPC_PINCON_PINSEL2_P1_1SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL2_P1_1SEL_bit)
#define LPC_PINCON_PINSEL2_P1_1SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL2_P1_1SEL_bit)

#define LPC_PINCON_PINSEL2_P1_4SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL2_P1_4SEL_bit)
#define LPC_PINCON_PINSEL2_P1_4SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL2_P1_4SEL_bit)

#define LPC_PINCON_PINSEL2_P1_8SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL2_P1_8SEL_bit)
#define LPC_PINCON_PINSEL2_P1_8SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL2_P1_8SEL_bit)

#define LPC_PINCON_PINSEL2_P1_9SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL2_P1_9SEL_bit)
#define LPC_PINCON_PINSEL2_P1_9SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL2_P1_9SEL_bit)

#define LPC_PINCON_PINSEL2_P1_10SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL2_P1_10SEL_bit)
#define LPC_PINCON_PINSEL2_P1_10SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL2_P1_10SEL_bit)

#define LPC_PINCON_PINSEL2_P1_14SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL2_P1_14SEL_bit)
#define LPC_PINCON_PINSEL2_P1_14SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL2_P1_14SEL_bit)

#define LPC_PINCON_PINSEL2_P1_15SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL2_P1_15SEL_bit)
#define LPC_PINCON_PINSEL2_P1_15SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL2_P1_15SEL_bit)

#define LPC_PINCON_PINSEL2_P1_0SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_0SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_0SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_0SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_1SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_1SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_1SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_1SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_4SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_4SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_4SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_4SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_8SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_8SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_8SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_8SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_9SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_9SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_9SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_9SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_10SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_10SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_10SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_10SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_14SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_14SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_14SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_14SEL_1_bit)
#define LPC_PINCON_PINSEL2_P1_15SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_15SEL_0_bit)
#define LPC_PINCON_PINSEL2_P1_15SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL2, LPC_PINCON_PINSEL2_P1_15SEL_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINSEL3 - Pin function select register 3
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINSEL3_P1_16SEL_bit			0
#define LPC_PINCON_PINSEL3_P1_16SEL_0_bit		0
#define LPC_PINCON_PINSEL3_P1_16SEL_1_bit		1
#define LPC_PINCON_PINSEL3_P1_17SEL_bit			2
#define LPC_PINCON_PINSEL3_P1_17SEL_0_bit		2
#define LPC_PINCON_PINSEL3_P1_17SEL_1_bit		3
#define LPC_PINCON_PINSEL3_P1_18SEL_bit			4
#define LPC_PINCON_PINSEL3_P1_18SEL_0_bit		4
#define LPC_PINCON_PINSEL3_P1_18SEL_1_bit		5
#define LPC_PINCON_PINSEL3_P1_19SEL_bit			6
#define LPC_PINCON_PINSEL3_P1_19SEL_0_bit		6
#define LPC_PINCON_PINSEL3_P1_19SEL_1_bit		7
#define LPC_PINCON_PINSEL3_P1_20SEL_bit			8
#define LPC_PINCON_PINSEL3_P1_20SEL_0_bit		8
#define LPC_PINCON_PINSEL3_P1_20SEL_1_bit		9
#define LPC_PINCON_PINSEL3_P1_21SEL_bit			10
#define LPC_PINCON_PINSEL3_P1_21SEL_0_bit		10
#define LPC_PINCON_PINSEL3_P1_21SEL_1_bit		11
#define LPC_PINCON_PINSEL3_P1_22SEL_bit			12
#define LPC_PINCON_PINSEL3_P1_22SEL_0_bit		12
#define LPC_PINCON_PINSEL3_P1_22SEL_1_bit		13
#define LPC_PINCON_PINSEL3_P1_23SEL_bit			14
#define LPC_PINCON_PINSEL3_P1_23SEL_0_bit		14
#define LPC_PINCON_PINSEL3_P1_23SEL_1_bit		15
#define LPC_PINCON_PINSEL3_P1_24SEL_bit			16
#define LPC_PINCON_PINSEL3_P1_24SEL_0_bit		16
#define LPC_PINCON_PINSEL3_P1_24SEL_1_bit		17
#define LPC_PINCON_PINSEL3_P1_25SEL_bit			18
#define LPC_PINCON_PINSEL3_P1_25SEL_0_bit		18
#define LPC_PINCON_PINSEL3_P1_25SEL_1_bit		19
#define LPC_PINCON_PINSEL3_P1_26SEL_bit			20
#define LPC_PINCON_PINSEL3_P1_26SEL_0_bit		20
#define LPC_PINCON_PINSEL3_P1_26SEL_1_bit		21
#define LPC_PINCON_PINSEL3_P1_27SEL_bit			22
#define LPC_PINCON_PINSEL3_P1_27SEL_0_bit		22
#define LPC_PINCON_PINSEL3_P1_27SEL_1_bit		23
#define LPC_PINCON_PINSEL3_P1_28SEL_bit			24
#define LPC_PINCON_PINSEL3_P1_28SEL_0_bit		24
#define LPC_PINCON_PINSEL3_P1_28SEL_1_bit		25
#define LPC_PINCON_PINSEL3_P1_29SEL_bit			26
#define LPC_PINCON_PINSEL3_P1_29SEL_0_bit		26
#define LPC_PINCON_PINSEL3_P1_29SEL_1_bit		27
#define LPC_PINCON_PINSEL3_P1_30SEL_bit			28
#define LPC_PINCON_PINSEL3_P1_30SEL_0_bit		28
#define LPC_PINCON_PINSEL3_P1_30SEL_1_bit		29
#define LPC_PINCON_PINSEL3_P1_31SEL_bit			30
#define LPC_PINCON_PINSEL3_P1_31SEL_0_bit		30
#define LPC_PINCON_PINSEL3_P1_31SEL_1_bit		31

#define LPC_PINCON_PINSEL3_P1_16SEL_0			(1 << LPC_PINCON_PINSEL3_P1_16SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_16SEL_1			(1 << LPC_PINCON_PINSEL3_P1_16SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_17SEL_0			(1 << LPC_PINCON_PINSEL3_P1_17SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_17SEL_1			(1 << LPC_PINCON_PINSEL3_P1_17SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_18SEL_0			(1 << LPC_PINCON_PINSEL3_P1_18SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_18SEL_1			(1 << LPC_PINCON_PINSEL3_P1_18SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_19SEL_0			(1 << LPC_PINCON_PINSEL3_P1_19SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_19SEL_1			(1 << LPC_PINCON_PINSEL3_P1_19SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_20SEL_0			(1 << LPC_PINCON_PINSEL3_P1_20SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_20SEL_1			(1 << LPC_PINCON_PINSEL3_P1_20SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_21SEL_0			(1 << LPC_PINCON_PINSEL3_P1_21SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_21SEL_1			(1 << LPC_PINCON_PINSEL3_P1_21SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_22SEL_0			(1 << LPC_PINCON_PINSEL3_P1_22SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_22SEL_1			(1 << LPC_PINCON_PINSEL3_P1_22SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_23SEL_0			(1 << LPC_PINCON_PINSEL3_P1_23SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_23SEL_1			(1 << LPC_PINCON_PINSEL3_P1_23SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_24SEL_0			(1 << LPC_PINCON_PINSEL3_P1_24SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_24SEL_1			(1 << LPC_PINCON_PINSEL3_P1_24SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_25SEL_0			(1 << LPC_PINCON_PINSEL3_P1_25SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_25SEL_1			(1 << LPC_PINCON_PINSEL3_P1_25SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_26SEL_0			(1 << LPC_PINCON_PINSEL3_P1_26SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_26SEL_1			(1 << LPC_PINCON_PINSEL3_P1_26SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_27SEL_0			(1 << LPC_PINCON_PINSEL3_P1_27SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_27SEL_1			(1 << LPC_PINCON_PINSEL3_P1_27SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_28SEL_0			(1 << LPC_PINCON_PINSEL3_P1_28SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_28SEL_1			(1 << LPC_PINCON_PINSEL3_P1_28SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_29SEL_0			(1 << LPC_PINCON_PINSEL3_P1_29SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_29SEL_1			(1 << LPC_PINCON_PINSEL3_P1_29SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_30SEL_0			(1 << LPC_PINCON_PINSEL3_P1_30SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_30SEL_1			(1 << LPC_PINCON_PINSEL3_P1_30SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_31SEL_0			(1 << LPC_PINCON_PINSEL3_P1_31SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_31SEL_1			(1 << LPC_PINCON_PINSEL3_P1_31SEL_1_bit)

#define LPC_PINCON_PINSEL3_P1_16SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_16SEL_bit)
#define LPC_PINCON_PINSEL3_P1_16SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_16SEL_bit)

#define LPC_PINCON_PINSEL3_P1_17SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_17SEL_bit)
#define LPC_PINCON_PINSEL3_P1_17SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_17SEL_bit)

#define LPC_PINCON_PINSEL3_P1_18SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_18SEL_bit)
#define LPC_PINCON_PINSEL3_P1_18SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_18SEL_bit)
#define LPC_PINCON_PINSEL3_P1_18SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_18SEL_bit)
#define LPC_PINCON_PINSEL3_P1_18SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_18SEL_bit)

#define LPC_PINCON_PINSEL3_P1_19SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_19SEL_bit)
#define LPC_PINCON_PINSEL3_P1_19SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_19SEL_bit)
#define LPC_PINCON_PINSEL3_P1_19SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_19SEL_bit)
#define LPC_PINCON_PINSEL3_P1_19SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_19SEL_bit)

#define LPC_PINCON_PINSEL3_P1_20SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_20SEL_bit)
#define LPC_PINCON_PINSEL3_P1_20SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_20SEL_bit)
#define LPC_PINCON_PINSEL3_P1_20SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_20SEL_bit)
#define LPC_PINCON_PINSEL3_P1_20SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_20SEL_bit)

#define LPC_PINCON_PINSEL3_P1_21SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_21SEL_bit)
#define LPC_PINCON_PINSEL3_P1_21SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_21SEL_bit)
#define LPC_PINCON_PINSEL3_P1_21SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_21SEL_bit)
#define LPC_PINCON_PINSEL3_P1_21SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_21SEL_bit)

#define LPC_PINCON_PINSEL3_P1_22SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_22SEL_bit)
#define LPC_PINCON_PINSEL3_P1_22SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_22SEL_bit)
#define LPC_PINCON_PINSEL3_P1_22SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_22SEL_bit)
#define LPC_PINCON_PINSEL3_P1_22SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_22SEL_bit)

#define LPC_PINCON_PINSEL3_P1_23SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_23SEL_bit)
#define LPC_PINCON_PINSEL3_P1_23SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_23SEL_bit)
#define LPC_PINCON_PINSEL3_P1_23SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_23SEL_bit)
#define LPC_PINCON_PINSEL3_P1_23SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_23SEL_bit)

#define LPC_PINCON_PINSEL3_P1_24SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_24SEL_bit)
#define LPC_PINCON_PINSEL3_P1_24SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_24SEL_bit)
#define LPC_PINCON_PINSEL3_P1_24SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_24SEL_bit)
#define LPC_PINCON_PINSEL3_P1_24SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_24SEL_bit)

#define LPC_PINCON_PINSEL3_P1_25SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_25SEL_bit)
#define LPC_PINCON_PINSEL3_P1_25SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_25SEL_bit)
#define LPC_PINCON_PINSEL3_P1_25SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_25SEL_bit)

#define LPC_PINCON_PINSEL3_P1_26SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_26SEL_bit)
#define LPC_PINCON_PINSEL3_P1_26SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_26SEL_bit)
#define LPC_PINCON_PINSEL3_P1_26SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_26SEL_bit)
#define LPC_PINCON_PINSEL3_P1_26SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_26SEL_bit)

#define LPC_PINCON_PINSEL3_P1_27SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_27SEL_bit)
#define LPC_PINCON_PINSEL3_P1_27SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_27SEL_bit)
#define LPC_PINCON_PINSEL3_P1_27SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_27SEL_bit)
#define LPC_PINCON_PINSEL3_P1_27SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_27SEL_bit)

#define LPC_PINCON_PINSEL3_P1_28SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_28SEL_bit)
#define LPC_PINCON_PINSEL3_P1_28SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_28SEL_bit)
#define LPC_PINCON_PINSEL3_P1_28SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_28SEL_bit)
#define LPC_PINCON_PINSEL3_P1_28SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_28SEL_bit)

#define LPC_PINCON_PINSEL3_P1_29SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_29SEL_bit)
#define LPC_PINCON_PINSEL3_P1_29SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL3_P1_29SEL_bit)
#define LPC_PINCON_PINSEL3_P1_29SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_29SEL_bit)
#define LPC_PINCON_PINSEL3_P1_29SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_29SEL_bit)

#define LPC_PINCON_PINSEL3_P1_30SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_30SEL_bit)
#define LPC_PINCON_PINSEL3_P1_30SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_30SEL_bit)
#define LPC_PINCON_PINSEL3_P1_30SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_30SEL_bit)

#define LPC_PINCON_PINSEL3_P1_31SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL3_P1_31SEL_bit)
#define LPC_PINCON_PINSEL3_P1_31SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL3_P1_31SEL_bit)
#define LPC_PINCON_PINSEL3_P1_31SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL3_P1_31SEL_bit)

#define LPC_PINCON_PINSEL3_P1_16SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_16SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_16SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_16SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_17SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_17SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_17SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_17SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_18SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_18SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_18SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_18SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_19SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_19SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_19SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_19SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_20SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_20SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_20SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_20SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_21SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_21SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_21SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_21SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_22SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_22SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_22SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_22SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_23SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_23SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_23SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_23SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_24SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_24SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_24SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_24SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_25SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_25SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_25SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_25SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_26SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_26SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_26SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_26SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_27SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_27SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_27SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_27SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_28SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_28SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_28SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_28SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_29SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_29SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_29SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_29SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_30SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_30SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_30SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_30SEL_1_bit)
#define LPC_PINCON_PINSEL3_P1_31SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_31SEL_0_bit)
#define LPC_PINCON_PINSEL3_P1_31SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL3, LPC_PINCON_PINSEL3_P1_31SEL_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINSEL4 - Pin function select register 4
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINSEL4_P2_0SEL_bit			0
#define LPC_PINCON_PINSEL4_P2_0SEL_0_bit		0
#define LPC_PINCON_PINSEL4_P2_0SEL_1_bit		1
#define LPC_PINCON_PINSEL4_P2_1SEL_bit			2
#define LPC_PINCON_PINSEL4_P2_1SEL_0_bit		2
#define LPC_PINCON_PINSEL4_P2_1SEL_1_bit		3
#define LPC_PINCON_PINSEL4_P2_2SEL_bit			4
#define LPC_PINCON_PINSEL4_P2_2SEL_0_bit		4
#define LPC_PINCON_PINSEL4_P2_2SEL_1_bit		5
#define LPC_PINCON_PINSEL4_P2_3SEL_bit			6
#define LPC_PINCON_PINSEL4_P2_3SEL_0_bit		6
#define LPC_PINCON_PINSEL4_P2_3SEL_1_bit		7
#define LPC_PINCON_PINSEL4_P2_4SEL_bit			8
#define LPC_PINCON_PINSEL4_P2_4SEL_0_bit		8
#define LPC_PINCON_PINSEL4_P2_4SEL_1_bit		9
#define LPC_PINCON_PINSEL4_P2_5SEL_bit			10
#define LPC_PINCON_PINSEL4_P2_5SEL_0_bit		10
#define LPC_PINCON_PINSEL4_P2_5SEL_1_bit		11
#define LPC_PINCON_PINSEL4_P2_6SEL_bit			12
#define LPC_PINCON_PINSEL4_P2_6SEL_0_bit		12
#define LPC_PINCON_PINSEL4_P2_6SEL_1_bit		13
#define LPC_PINCON_PINSEL4_P2_7SEL_bit			14
#define LPC_PINCON_PINSEL4_P2_7SEL_0_bit		14
#define LPC_PINCON_PINSEL4_P2_7SEL_1_bit		15
#define LPC_PINCON_PINSEL4_P2_8SEL_bit			16
#define LPC_PINCON_PINSEL4_P2_8SEL_0_bit		16
#define LPC_PINCON_PINSEL4_P2_8SEL_1_bit		17
#define LPC_PINCON_PINSEL4_P2_9SEL_bit			18
#define LPC_PINCON_PINSEL4_P2_9SEL_0_bit		18
#define LPC_PINCON_PINSEL4_P2_9SEL_1_bit		19
#define LPC_PINCON_PINSEL4_P2_10SEL_bit			20
#define LPC_PINCON_PINSEL4_P2_10SEL_0_bit		20
#define LPC_PINCON_PINSEL4_P2_10SEL_1_bit		21
#define LPC_PINCON_PINSEL4_P2_11SEL_bit			22
#define LPC_PINCON_PINSEL4_P2_11SEL_0_bit		22
#define LPC_PINCON_PINSEL4_P2_11SEL_1_bit		23
#define LPC_PINCON_PINSEL4_P2_12SEL_bit			24
#define LPC_PINCON_PINSEL4_P2_12SEL_0_bit		24
#define LPC_PINCON_PINSEL4_P2_12SEL_1_bit		25
#define LPC_PINCON_PINSEL4_P2_13SEL_bit			26
#define LPC_PINCON_PINSEL4_P2_13SEL_0_bit		26
#define LPC_PINCON_PINSEL4_P2_13SEL_1_bit		27

#define LPC_PINCON_PINSEL4_P2_0SEL_0			(1 << LPC_PINCON_PINSEL4_P2_0SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_0SEL_1			(1 << LPC_PINCON_PINSEL4_P2_0SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_1SEL_0			(1 << LPC_PINCON_PINSEL4_P2_1SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_1SEL_1			(1 << LPC_PINCON_PINSEL4_P2_1SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_2SEL_0			(1 << LPC_PINCON_PINSEL4_P2_2SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_2SEL_1			(1 << LPC_PINCON_PINSEL4_P2_2SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_3SEL_0			(1 << LPC_PINCON_PINSEL4_P2_3SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_3SEL_1			(1 << LPC_PINCON_PINSEL4_P2_3SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_4SEL_0			(1 << LPC_PINCON_PINSEL4_P2_4SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_4SEL_1			(1 << LPC_PINCON_PINSEL4_P2_4SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_5SEL_0			(1 << LPC_PINCON_PINSEL4_P2_5SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_5SEL_1			(1 << LPC_PINCON_PINSEL4_P2_5SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_6SEL_0			(1 << LPC_PINCON_PINSEL4_P2_6SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_6SEL_1			(1 << LPC_PINCON_PINSEL4_P2_6SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_7SEL_0			(1 << LPC_PINCON_PINSEL4_P2_7SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_7SEL_1			(1 << LPC_PINCON_PINSEL4_P2_7SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_8SEL_0			(1 << LPC_PINCON_PINSEL4_P2_8SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_8SEL_1			(1 << LPC_PINCON_PINSEL4_P2_8SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_9SEL_0			(1 << LPC_PINCON_PINSEL4_P2_9SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_9SEL_1			(1 << LPC_PINCON_PINSEL4_P2_9SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_10SEL_0			(1 << LPC_PINCON_PINSEL4_P2_10SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_10SEL_1			(1 << LPC_PINCON_PINSEL4_P2_10SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_11SEL_0			(1 << LPC_PINCON_PINSEL4_P2_11SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_11SEL_1			(1 << LPC_PINCON_PINSEL4_P2_11SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_12SEL_0			(1 << LPC_PINCON_PINSEL4_P2_12SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_12SEL_1			(1 << LPC_PINCON_PINSEL4_P2_12SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_13SEL_0			(1 << LPC_PINCON_PINSEL4_P2_13SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_13SEL_1			(1 << LPC_PINCON_PINSEL4_P2_13SEL_1_bit)

#define LPC_PINCON_PINSEL4_P2_0SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_0SEL_bit)
#define LPC_PINCON_PINSEL4_P2_0SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_0SEL_bit)
#define LPC_PINCON_PINSEL4_P2_0SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_0SEL_bit)

#define LPC_PINCON_PINSEL4_P2_1SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_1SEL_bit)
#define LPC_PINCON_PINSEL4_P2_1SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_1SEL_bit)
#define LPC_PINCON_PINSEL4_P2_1SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_1SEL_bit)

#define LPC_PINCON_PINSEL4_P2_2SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_2SEL_bit)
#define LPC_PINCON_PINSEL4_P2_2SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_2SEL_bit)
#define LPC_PINCON_PINSEL4_P2_2SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_2SEL_bit)

#define LPC_PINCON_PINSEL4_P2_3SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_3SEL_bit)
#define LPC_PINCON_PINSEL4_P2_3SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_3SEL_bit)
#define LPC_PINCON_PINSEL4_P2_3SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_3SEL_bit)

#define LPC_PINCON_PINSEL4_P2_4SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_4SEL_bit)
#define LPC_PINCON_PINSEL4_P2_4SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_4SEL_bit)
#define LPC_PINCON_PINSEL4_P2_4SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_4SEL_bit)

#define LPC_PINCON_PINSEL4_P2_5SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_5SEL_bit)
#define LPC_PINCON_PINSEL4_P2_5SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_5SEL_bit)
#define LPC_PINCON_PINSEL4_P2_5SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_5SEL_bit)

#define LPC_PINCON_PINSEL4_P2_6SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_6SEL_bit)
#define LPC_PINCON_PINSEL4_P2_6SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_6SEL_bit)
#define LPC_PINCON_PINSEL4_P2_6SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_6SEL_bit)

#define LPC_PINCON_PINSEL4_P2_7SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_7SEL_bit)
#define LPC_PINCON_PINSEL4_P2_7SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_7SEL_bit)
#define LPC_PINCON_PINSEL4_P2_7SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_7SEL_bit)

#define LPC_PINCON_PINSEL4_P2_8SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_8SEL_bit)
#define LPC_PINCON_PINSEL4_P2_8SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_8SEL_bit)
#define LPC_PINCON_PINSEL4_P2_8SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_8SEL_bit)
#define LPC_PINCON_PINSEL4_P2_8SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL4_P2_8SEL_bit)

#define LPC_PINCON_PINSEL4_P2_9SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_9SEL_bit)
#define LPC_PINCON_PINSEL4_P2_9SEL_ALT1			(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_9SEL_bit)
#define LPC_PINCON_PINSEL4_P2_9SEL_ALT2			(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_9SEL_bit)
#define LPC_PINCON_PINSEL4_P2_9SEL_ALT3			(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL4_P2_9SEL_bit)

#define LPC_PINCON_PINSEL4_P2_10SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_10SEL_bit)
#define LPC_PINCON_PINSEL4_P2_10SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_10SEL_bit)
#define LPC_PINCON_PINSEL4_P2_10SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL4_P2_10SEL_bit)

#define LPC_PINCON_PINSEL4_P2_11SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_11SEL_bit)
#define LPC_PINCON_PINSEL4_P2_11SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_11SEL_bit)
#define LPC_PINCON_PINSEL4_P2_11SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL4_P2_11SEL_bit)

#define LPC_PINCON_PINSEL4_P2_12SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_12SEL_bit)
#define LPC_PINCON_PINSEL4_P2_12SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_12SEL_bit)
#define LPC_PINCON_PINSEL4_P2_12SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL4_P2_12SEL_bit)

#define LPC_PINCON_PINSEL4_P2_13SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL4_P2_13SEL_bit)
#define LPC_PINCON_PINSEL4_P2_13SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL4_P2_13SEL_bit)
#define LPC_PINCON_PINSEL4_P2_13SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL4_P2_13SEL_bit)

#define LPC_PINCON_PINSEL4_P2_0SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_0SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_0SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_0SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_1SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_1SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_1SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_1SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_2SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_2SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_2SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_2SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_3SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_3SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_3SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_3SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_4SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_4SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_4SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_4SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_5SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_5SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_5SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_5SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_6SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_6SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_6SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_6SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_7SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_7SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_7SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_7SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_8SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_8SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_8SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_8SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_9SEL_0_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_9SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_9SEL_1_bb			bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_9SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_10SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_10SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_10SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_10SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_11SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_11SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_11SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_11SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_12SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_12SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_12SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_12SEL_1_bit)
#define LPC_PINCON_PINSEL4_P2_13SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_13SEL_0_bit)
#define LPC_PINCON_PINSEL4_P2_13SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL4, LPC_PINCON_PINSEL4_P2_13SEL_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINSEL7 - Pin function select register 7
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINSEL7_P3_25SEL_bit			18
#define LPC_PINCON_PINSEL7_P3_25SEL_0_bit		18
#define LPC_PINCON_PINSEL7_P3_25SEL_1_bit		19
#define LPC_PINCON_PINSEL7_P3_26SEL_bit			20
#define LPC_PINCON_PINSEL7_P3_26SEL_0_bit		20
#define LPC_PINCON_PINSEL7_P3_26SEL_1_bit		21

#define LPC_PINCON_PINSEL7_P3_25SEL_0			(1 << LPC_PINCON_PINSEL7_P3_25SEL_0_bit)
#define LPC_PINCON_PINSEL7_P3_25SEL_1			(1 << LPC_PINCON_PINSEL7_P3_25SEL_1_bit)
#define LPC_PINCON_PINSEL7_P3_26SEL_0			(1 << LPC_PINCON_PINSEL7_P3_26SEL_0_bit)
#define LPC_PINCON_PINSEL7_P3_26SEL_1			(1 << LPC_PINCON_PINSEL7_P3_26SEL_1_bit)

#define LPC_PINCON_PINSEL7_P3_25SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL7_P3_25SEL_bit)
#define LPC_PINCON_PINSEL7_P3_25SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL7_P3_25SEL_bit)
#define LPC_PINCON_PINSEL7_P3_25SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL7_P3_25SEL_bit)

#define LPC_PINCON_PINSEL7_P3_26SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL7_P3_26SEL_bit)
#define LPC_PINCON_PINSEL7_P3_26SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL7_P3_26SEL_bit)
#define LPC_PINCON_PINSEL7_P3_26SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL7_P3_26SEL_bit)
#define LPC_PINCON_PINSEL7_P3_26SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL7_P3_26SEL_bit)

#define LPC_PINCON_PINSEL7_P3_25SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL7, LPC_PINCON_PINSEL7_P3_25SEL_0_bit)
#define LPC_PINCON_PINSEL7_P3_25SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL7, LPC_PINCON_PINSEL7_P3_25SEL_1_bit)
#define LPC_PINCON_PINSEL7_P3_26SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL7, LPC_PINCON_PINSEL7_P3_26SEL_0_bit)
#define LPC_PINCON_PINSEL7_P3_26SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL7, LPC_PINCON_PINSEL7_P3_26SEL_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINSEL9 - Pin function select register 9
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINSEL9_P4_28SEL_bit			24
#define LPC_PINCON_PINSEL9_P4_28SEL_0_bit		24
#define LPC_PINCON_PINSEL9_P4_28SEL_1_bit		25
#define LPC_PINCON_PINSEL9_P4_29SEL_bit			26
#define LPC_PINCON_PINSEL9_P4_29SEL_0_bit		26
#define LPC_PINCON_PINSEL9_P4_29SEL_1_bit		27

#define LPC_PINCON_PINSEL9_P4_28SEL_0			(1 << LPC_PINCON_PINSEL9_P4_28SEL_0_bit)
#define LPC_PINCON_PINSEL9_P4_28SEL_1			(1 << LPC_PINCON_PINSEL9_P4_28SEL_1_bit)
#define LPC_PINCON_PINSEL9_P4_29SEL_0			(1 << LPC_PINCON_PINSEL9_P4_29SEL_0_bit)
#define LPC_PINCON_PINSEL9_P4_29SEL_1			(1 << LPC_PINCON_PINSEL9_P4_29SEL_1_bit)

#define LPC_PINCON_PINSEL9_P4_28SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL9_P4_28SEL_bit)
#define LPC_PINCON_PINSEL9_P4_28SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL9_P4_28SEL_bit)
#define LPC_PINCON_PINSEL9_P4_28SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL9_P4_28SEL_bit)
#define LPC_PINCON_PINSEL9_P4_28SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL9_P4_28SEL_bit)

#define LPC_PINCON_PINSEL9_P4_29SEL_DEFAULT		(LPC_PINCON_PINSELx_DEFAULT_value << LPC_PINCON_PINSEL9_P4_29SEL_bit)
#define LPC_PINCON_PINSEL9_P4_29SEL_ALT1		(LPC_PINCON_PINSELx_ALT1_value << LPC_PINCON_PINSEL9_P4_29SEL_bit)
#define LPC_PINCON_PINSEL9_P4_29SEL_ALT2		(LPC_PINCON_PINSELx_ALT2_value << LPC_PINCON_PINSEL9_P4_29SEL_bit)
#define LPC_PINCON_PINSEL9_P4_29SEL_ALT3		(LPC_PINCON_PINSELx_ALT3_value << LPC_PINCON_PINSEL9_P4_29SEL_bit)

#define LPC_PINCON_PINSEL9_P4_28SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL9, LPC_PINCON_PINSEL9_P4_28SEL_0_bit)
#define LPC_PINCON_PINSEL9_P4_28SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL9, LPC_PINCON_PINSEL9_P4_28SEL_1_bit)
#define LPC_PINCON_PINSEL9_P4_29SEL_0_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL9, LPC_PINCON_PINSEL9_P4_29SEL_0_bit)
#define LPC_PINCON_PINSEL9_P4_29SEL_1_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL9, LPC_PINCON_PINSEL9_P4_29SEL_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINSEL10 - Pin function select register 10
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINSEL10_GPIO_TRACE_bit		3

#define LPC_PINCON_PINSEL10_GPIO_TRACE			(1 << LPC_PINCON_PINSEL10_GPIO_TRACE_bit)

#define LPC_PINCON_PINSEL10_GPIO_TRACE_bb		bitband_t BITBAND(&LPC_PINCON->PINSEL10, LPC_PINCON_PINSEL10_GPIO_TRACE_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE0 - Pin Mode select register 0
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE0_P0_0MODE_bit		0
#define LPC_PINCON_PINMODE0_P0_0MODE_0_bit		0
#define LPC_PINCON_PINMODE0_P0_0MODE_1_bit		1
#define LPC_PINCON_PINMODE0_P0_1MODE_bit		2
#define LPC_PINCON_PINMODE0_P0_1MODE_0_bit		2
#define LPC_PINCON_PINMODE0_P0_1MODE_1_bit		3
#define LPC_PINCON_PINMODE0_P0_2MODE_bit		4
#define LPC_PINCON_PINMODE0_P0_2MODE_0_bit		4
#define LPC_PINCON_PINMODE0_P0_2MODE_1_bit		5
#define LPC_PINCON_PINMODE0_P0_3MODE_bit		6
#define LPC_PINCON_PINMODE0_P0_3MODE_0_bit		6
#define LPC_PINCON_PINMODE0_P0_3MODE_1_bit		7
#define LPC_PINCON_PINMODE0_P0_4MODE_bit		8
#define LPC_PINCON_PINMODE0_P0_4MODE_0_bit		8
#define LPC_PINCON_PINMODE0_P0_4MODE_1_bit		9
#define LPC_PINCON_PINMODE0_P0_5MODE_bit		10
#define LPC_PINCON_PINMODE0_P0_5MODE_0_bit		10
#define LPC_PINCON_PINMODE0_P0_5MODE_1_bit		11
#define LPC_PINCON_PINMODE0_P0_6MODE_bit		12
#define LPC_PINCON_PINMODE0_P0_6MODE_0_bit		12
#define LPC_PINCON_PINMODE0_P0_6MODE_1_bit		13
#define LPC_PINCON_PINMODE0_P0_7MODE_bit		14
#define LPC_PINCON_PINMODE0_P0_7MODE_0_bit		14
#define LPC_PINCON_PINMODE0_P0_7MODE_1_bit		15
#define LPC_PINCON_PINMODE0_P0_8MODE_bit		16
#define LPC_PINCON_PINMODE0_P0_8MODE_0_bit		16
#define LPC_PINCON_PINMODE0_P0_8MODE_1_bit		17
#define LPC_PINCON_PINMODE0_P0_9MODE_bit		18
#define LPC_PINCON_PINMODE0_P0_9MODE_0_bit		18
#define LPC_PINCON_PINMODE0_P0_9MODE_1_bit		19
#define LPC_PINCON_PINMODE0_P0_10MODE_bit		20
#define LPC_PINCON_PINMODE0_P0_10MODE_0_bit		20
#define LPC_PINCON_PINMODE0_P0_10MODE_1_bit		21
#define LPC_PINCON_PINMODE0_P0_11MODE_bit		22
#define LPC_PINCON_PINMODE0_P0_11MODE_0_bit		22
#define LPC_PINCON_PINMODE0_P0_11MODE_1_bit		23
#define LPC_PINCON_PINMODE0_P0_15MODE_bit		30
#define LPC_PINCON_PINMODE0_P0_15MODE_0_bit		30
#define LPC_PINCON_PINMODE0_P0_15MODE_1_bit		31

#define LPC_PINCON_PINMODE0_P0_0MODE_0			(1 << LPC_PINCON_PINMODE0_P0_0MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_0MODE_1			(1 << LPC_PINCON_PINMODE0_P0_0MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_1MODE_0			(1 << LPC_PINCON_PINMODE0_P0_1MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_1MODE_1			(1 << LPC_PINCON_PINMODE0_P0_1MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_2MODE_0			(1 << LPC_PINCON_PINMODE0_P0_2MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_2MODE_1			(1 << LPC_PINCON_PINMODE0_P0_2MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_3MODE_0			(1 << LPC_PINCON_PINMODE0_P0_3MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_3MODE_1			(1 << LPC_PINCON_PINMODE0_P0_3MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_4MODE_0			(1 << LPC_PINCON_PINMODE0_P0_4MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_4MODE_1			(1 << LPC_PINCON_PINMODE0_P0_4MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_5MODE_0			(1 << LPC_PINCON_PINMODE0_P0_5MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_5MODE_1			(1 << LPC_PINCON_PINMODE0_P0_5MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_6MODE_0			(1 << LPC_PINCON_PINMODE0_P0_6MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_6MODE_1			(1 << LPC_PINCON_PINMODE0_P0_6MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_7MODE_0			(1 << LPC_PINCON_PINMODE0_P0_7MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_7MODE_1			(1 << LPC_PINCON_PINMODE0_P0_7MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_8MODE_0			(1 << LPC_PINCON_PINMODE0_P0_8MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_8MODE_1			(1 << LPC_PINCON_PINMODE0_P0_8MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_9MODE_0			(1 << LPC_PINCON_PINMODE0_P0_9MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_9MODE_1			(1 << LPC_PINCON_PINMODE0_P0_9MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_10MODE_0			(1 << LPC_PINCON_PINMODE0_P0_10MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_10MODE_1			(1 << LPC_PINCON_PINMODE0_P0_10MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_11MODE_0			(1 << LPC_PINCON_PINMODE0_P0_11MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_11MODE_1			(1 << LPC_PINCON_PINMODE0_P0_11MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_15MODE_0			(1 << LPC_PINCON_PINMODE0_P0_15MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_15MODE_1			(1 << LPC_PINCON_PINMODE0_P0_15MODE_1_bit)

#define LPC_PINCON_PINMODE0_P0_0MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_0MODE_bit)
#define LPC_PINCON_PINMODE0_P0_0MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_0MODE_bit)
#define LPC_PINCON_PINMODE0_P0_0MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_0MODE_bit)
#define LPC_PINCON_PINMODE0_P0_0MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_0MODE_bit)

#define LPC_PINCON_PINMODE0_P0_1MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_1MODE_bit)
#define LPC_PINCON_PINMODE0_P0_1MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_1MODE_bit)
#define LPC_PINCON_PINMODE0_P0_1MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_1MODE_bit)
#define LPC_PINCON_PINMODE0_P0_1MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_1MODE_bit)

#define LPC_PINCON_PINMODE0_P0_2MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_2MODE_bit)
#define LPC_PINCON_PINMODE0_P0_2MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_2MODE_bit)
#define LPC_PINCON_PINMODE0_P0_2MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_2MODE_bit)
#define LPC_PINCON_PINMODE0_P0_2MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_2MODE_bit)

#define LPC_PINCON_PINMODE0_P0_3MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_3MODE_bit)
#define LPC_PINCON_PINMODE0_P0_3MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_3MODE_bit)
#define LPC_PINCON_PINMODE0_P0_3MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_3MODE_bit)
#define LPC_PINCON_PINMODE0_P0_3MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_3MODE_bit)

#define LPC_PINCON_PINMODE0_P0_4MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_4MODE_bit)
#define LPC_PINCON_PINMODE0_P0_4MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_4MODE_bit)
#define LPC_PINCON_PINMODE0_P0_4MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_4MODE_bit)
#define LPC_PINCON_PINMODE0_P0_4MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_4MODE_bit)

#define LPC_PINCON_PINMODE0_P0_5MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_5MODE_bit)
#define LPC_PINCON_PINMODE0_P0_5MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_5MODE_bit)
#define LPC_PINCON_PINMODE0_P0_5MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_5MODE_bit)
#define LPC_PINCON_PINMODE0_P0_5MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_5MODE_bit)

#define LPC_PINCON_PINMODE0_P0_6MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_6MODE_bit)
#define LPC_PINCON_PINMODE0_P0_6MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_6MODE_bit)
#define LPC_PINCON_PINMODE0_P0_6MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_6MODE_bit)
#define LPC_PINCON_PINMODE0_P0_6MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_6MODE_bit)

#define LPC_PINCON_PINMODE0_P0_7MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_7MODE_bit)
#define LPC_PINCON_PINMODE0_P0_7MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_7MODE_bit)
#define LPC_PINCON_PINMODE0_P0_7MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_7MODE_bit)
#define LPC_PINCON_PINMODE0_P0_7MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_7MODE_bit)

#define LPC_PINCON_PINMODE0_P0_8MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_8MODE_bit)
#define LPC_PINCON_PINMODE0_P0_8MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_8MODE_bit)
#define LPC_PINCON_PINMODE0_P0_8MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_8MODE_bit)
#define LPC_PINCON_PINMODE0_P0_8MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_8MODE_bit)

#define LPC_PINCON_PINMODE0_P0_9MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_9MODE_bit)
#define LPC_PINCON_PINMODE0_P0_9MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_9MODE_bit)
#define LPC_PINCON_PINMODE0_P0_9MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_9MODE_bit)
#define LPC_PINCON_PINMODE0_P0_9MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_9MODE_bit)

#define LPC_PINCON_PINMODE0_P0_10MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_10MODE_bit)
#define LPC_PINCON_PINMODE0_P0_10MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_10MODE_bit)
#define LPC_PINCON_PINMODE0_P0_10MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_10MODE_bit)
#define LPC_PINCON_PINMODE0_P0_10MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_10MODE_bit)

#define LPC_PINCON_PINMODE0_P0_11MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_11MODE_bit)
#define LPC_PINCON_PINMODE0_P0_11MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_11MODE_bit)
#define LPC_PINCON_PINMODE0_P0_11MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_11MODE_bit)
#define LPC_PINCON_PINMODE0_P0_11MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_11MODE_bit)

#define LPC_PINCON_PINMODE0_P0_15MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE0_P0_15MODE_bit)
#define LPC_PINCON_PINMODE0_P0_15MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE0_P0_15MODE_bit)
#define LPC_PINCON_PINMODE0_P0_15MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE0_P0_15MODE_bit)
#define LPC_PINCON_PINMODE0_P0_15MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE0_P0_15MODE_bit)

#define LPC_PINCON_PINMODE0_P0_0MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_0MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_0MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_0MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_1MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_1MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_1MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_1MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_2MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_2MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_2MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_2MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_3MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_3MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_3MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_3MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_4MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_4MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_4MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_4MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_5MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_5MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_5MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_5MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_6MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_6MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_6MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_6MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_7MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_7MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_7MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_7MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_8MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_8MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_8MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_8MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_9MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_9MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_9MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_9MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_10MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_10MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_10MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_10MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_11MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_11MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_11MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_11MODE_1_bit)
#define LPC_PINCON_PINMODE0_P0_15MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_15MODE_0_bit)
#define LPC_PINCON_PINMODE0_P0_15MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE0, LPC_PINCON_PINMODE0_P0_15MODE_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE1 - Pin Mode select register 1
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE1_P0_16MODE_bit		0
#define LPC_PINCON_PINMODE1_P0_16MODE_0_bit		0
#define LPC_PINCON_PINMODE1_P0_16MODE_1_bit		1
#define LPC_PINCON_PINMODE1_P0_17MODE_bit		2
#define LPC_PINCON_PINMODE1_P0_17MODE_0_bit		2
#define LPC_PINCON_PINMODE1_P0_17MODE_1_bit		3
#define LPC_PINCON_PINMODE1_P0_18MODE_bit		4
#define LPC_PINCON_PINMODE1_P0_18MODE_0_bit		4
#define LPC_PINCON_PINMODE1_P0_18MODE_1_bit		5
#define LPC_PINCON_PINMODE1_P0_19MODE_bit		6
#define LPC_PINCON_PINMODE1_P0_19MODE_0_bit		6
#define LPC_PINCON_PINMODE1_P0_19MODE_1_bit		7
#define LPC_PINCON_PINMODE1_P0_20MODE_bit		8
#define LPC_PINCON_PINMODE1_P0_20MODE_0_bit		8
#define LPC_PINCON_PINMODE1_P0_20MODE_1_bit		9
#define LPC_PINCON_PINMODE1_P0_21MODE_bit		10
#define LPC_PINCON_PINMODE1_P0_21MODE_0_bit		10
#define LPC_PINCON_PINMODE1_P0_21MODE_1_bit		11
#define LPC_PINCON_PINMODE1_P0_22MODE_bit		12
#define LPC_PINCON_PINMODE1_P0_22MODE_0_bit		12
#define LPC_PINCON_PINMODE1_P0_22MODE_1_bit		13
#define LPC_PINCON_PINMODE1_P0_23MODE_bit		14
#define LPC_PINCON_PINMODE1_P0_23MODE_0_bit		14
#define LPC_PINCON_PINMODE1_P0_23MODE_1_bit		15
#define LPC_PINCON_PINMODE1_P0_24MODE_bit		16
#define LPC_PINCON_PINMODE1_P0_24MODE_0_bit		16
#define LPC_PINCON_PINMODE1_P0_24MODE_1_bit		17
#define LPC_PINCON_PINMODE1_P0_25MODE_bit		18
#define LPC_PINCON_PINMODE1_P0_25MODE_0_bit		18
#define LPC_PINCON_PINMODE1_P0_25MODE_1_bit		19
#define LPC_PINCON_PINMODE1_P0_26MODE_bit		20
#define LPC_PINCON_PINMODE1_P0_26MODE_0_bit		20
#define LPC_PINCON_PINMODE1_P0_26MODE_1_bit		21

#define LPC_PINCON_PINMODE1_P0_16MODE_0			(1 << LPC_PINCON_PINMODE1_P0_16MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_16MODE_1			(1 << LPC_PINCON_PINMODE1_P0_16MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_17MODE_0			(1 << LPC_PINCON_PINMODE1_P0_17MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_17MODE_1			(1 << LPC_PINCON_PINMODE1_P0_17MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_18MODE_0			(1 << LPC_PINCON_PINMODE1_P0_18MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_18MODE_1			(1 << LPC_PINCON_PINMODE1_P0_18MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_19MODE_0			(1 << LPC_PINCON_PINMODE1_P0_19MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_19MODE_1			(1 << LPC_PINCON_PINMODE1_P0_19MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_20MODE_0			(1 << LPC_PINCON_PINMODE1_P0_20MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_20MODE_1			(1 << LPC_PINCON_PINMODE1_P0_20MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_21MODE_0			(1 << LPC_PINCON_PINMODE1_P0_21MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_21MODE_1			(1 << LPC_PINCON_PINMODE1_P0_21MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_22MODE_0			(1 << LPC_PINCON_PINMODE1_P0_22MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_22MODE_1			(1 << LPC_PINCON_PINMODE1_P0_22MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_23MODE_0			(1 << LPC_PINCON_PINMODE1_P0_23MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_23MODE_1			(1 << LPC_PINCON_PINMODE1_P0_23MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_24MODE_0			(1 << LPC_PINCON_PINMODE1_P0_24MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_24MODE_1			(1 << LPC_PINCON_PINMODE1_P0_24MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_25MODE_0			(1 << LPC_PINCON_PINMODE1_P0_25MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_25MODE_1			(1 << LPC_PINCON_PINMODE1_P0_25MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_26MODE_0			(1 << LPC_PINCON_PINMODE1_P0_26MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_26MODE_1			(1 << LPC_PINCON_PINMODE1_P0_26MODE_1_bit)

#define LPC_PINCON_PINMODE1_P0_16MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_16MODE_bit)
#define LPC_PINCON_PINMODE1_P0_16MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_16MODE_bit)
#define LPC_PINCON_PINMODE1_P0_16MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_16MODE_bit)
#define LPC_PINCON_PINMODE1_P0_16MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_16MODE_bit)

#define LPC_PINCON_PINMODE1_P0_17MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_17MODE_bit)
#define LPC_PINCON_PINMODE1_P0_17MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_17MODE_bit)
#define LPC_PINCON_PINMODE1_P0_17MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_17MODE_bit)
#define LPC_PINCON_PINMODE1_P0_17MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_17MODE_bit)

#define LPC_PINCON_PINMODE1_P0_18MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_18MODE_bit)
#define LPC_PINCON_PINMODE1_P0_18MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_18MODE_bit)
#define LPC_PINCON_PINMODE1_P0_18MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_18MODE_bit)
#define LPC_PINCON_PINMODE1_P0_18MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_18MODE_bit)

#define LPC_PINCON_PINMODE1_P0_19MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_19MODE_bit)
#define LPC_PINCON_PINMODE1_P0_19MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_19MODE_bit)
#define LPC_PINCON_PINMODE1_P0_19MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_19MODE_bit)
#define LPC_PINCON_PINMODE1_P0_19MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_19MODE_bit)

#define LPC_PINCON_PINMODE1_P0_20MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_20MODE_bit)
#define LPC_PINCON_PINMODE1_P0_20MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_20MODE_bit)
#define LPC_PINCON_PINMODE1_P0_20MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_20MODE_bit)
#define LPC_PINCON_PINMODE1_P0_20MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_20MODE_bit)

#define LPC_PINCON_PINMODE1_P0_21MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_21MODE_bit)
#define LPC_PINCON_PINMODE1_P0_21MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_21MODE_bit)
#define LPC_PINCON_PINMODE1_P0_21MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_21MODE_bit)
#define LPC_PINCON_PINMODE1_P0_21MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_21MODE_bit)

#define LPC_PINCON_PINMODE1_P0_22MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_22MODE_bit)
#define LPC_PINCON_PINMODE1_P0_22MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_22MODE_bit)
#define LPC_PINCON_PINMODE1_P0_22MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_22MODE_bit)
#define LPC_PINCON_PINMODE1_P0_22MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_22MODE_bit)

#define LPC_PINCON_PINMODE1_P0_23MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_23MODE_bit)
#define LPC_PINCON_PINMODE1_P0_23MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_23MODE_bit)
#define LPC_PINCON_PINMODE1_P0_23MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_23MODE_bit)
#define LPC_PINCON_PINMODE1_P0_23MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_23MODE_bit)

#define LPC_PINCON_PINMODE1_P0_24MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_24MODE_bit)
#define LPC_PINCON_PINMODE1_P0_24MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_24MODE_bit)
#define LPC_PINCON_PINMODE1_P0_24MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_24MODE_bit)
#define LPC_PINCON_PINMODE1_P0_24MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_24MODE_bit)

#define LPC_PINCON_PINMODE1_P0_25MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_25MODE_bit)
#define LPC_PINCON_PINMODE1_P0_25MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_25MODE_bit)
#define LPC_PINCON_PINMODE1_P0_25MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_25MODE_bit)
#define LPC_PINCON_PINMODE1_P0_25MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_25MODE_bit)

#define LPC_PINCON_PINMODE1_P0_26MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE1_P0_26MODE_bit)
#define LPC_PINCON_PINMODE1_P0_26MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE1_P0_26MODE_bit)
#define LPC_PINCON_PINMODE1_P0_26MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE1_P0_26MODE_bit)
#define LPC_PINCON_PINMODE1_P0_26MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE1_P0_26MODE_bit)

#define LPC_PINCON_PINMODE1_P0_16MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_16MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_16MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_16MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_17MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_17MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_17MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_17MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_18MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_18MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_18MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_18MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_19MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_19MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_19MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_19MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_20MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_20MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_20MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_20MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_21MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_21MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_21MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_21MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_22MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_22MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_22MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_22MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_23MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_23MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_23MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_23MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_24MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_24MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_24MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_24MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_25MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_25MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_25MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_25MODE_1_bit)
#define LPC_PINCON_PINMODE1_P0_26MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_26MODE_0_bit)
#define LPC_PINCON_PINMODE1_P0_26MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE1, LPC_PINCON_PINMODE1_P0_26MODE_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE2 - Pin Mode select register 2
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE2_P1_0MODE_bit		0
#define LPC_PINCON_PINMODE2_P1_0MODE_0_bit		0
#define LPC_PINCON_PINMODE2_P1_0MODE_1_bit		1
#define LPC_PINCON_PINMODE2_P1_1MODE_bit		2
#define LPC_PINCON_PINMODE2_P1_1MODE_0_bit		2
#define LPC_PINCON_PINMODE2_P1_1MODE_1_bit		3
#define LPC_PINCON_PINMODE2_P1_4MODE_bit		8
#define LPC_PINCON_PINMODE2_P1_4MODE_0_bit		8
#define LPC_PINCON_PINMODE2_P1_4MODE_1_bit		9
#define LPC_PINCON_PINMODE2_P1_8MODE_bit		16
#define LPC_PINCON_PINMODE2_P1_8MODE_0_bit		16
#define LPC_PINCON_PINMODE2_P1_8MODE_1_bit		17
#define LPC_PINCON_PINMODE2_P1_9MODE_bit		18
#define LPC_PINCON_PINMODE2_P1_9MODE_0_bit		18
#define LPC_PINCON_PINMODE2_P1_9MODE_1_bit		19
#define LPC_PINCON_PINMODE2_P1_10MODE_bit		20
#define LPC_PINCON_PINMODE2_P1_10MODE_0_bit		20
#define LPC_PINCON_PINMODE2_P1_10MODE_1_bit		21
#define LPC_PINCON_PINMODE2_P1_14MODE_bit		28
#define LPC_PINCON_PINMODE2_P1_14MODE_0_bit		28
#define LPC_PINCON_PINMODE2_P1_14MODE_1_bit		29
#define LPC_PINCON_PINMODE2_P1_15MODE_bit		30
#define LPC_PINCON_PINMODE2_P1_15MODE_0_bit		30
#define LPC_PINCON_PINMODE2_P1_15MODE_1_bit		31

#define LPC_PINCON_PINMODE2_P1_0MODE_0			(1 << LPC_PINCON_PINMODE2_P1_0MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_0MODE_1			(1 << LPC_PINCON_PINMODE2_P1_0MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_1MODE_0			(1 << LPC_PINCON_PINMODE2_P1_1MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_1MODE_1			(1 << LPC_PINCON_PINMODE2_P1_1MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_4MODE_0			(1 << LPC_PINCON_PINMODE2_P1_4MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_4MODE_1			(1 << LPC_PINCON_PINMODE2_P1_4MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_8MODE_0			(1 << LPC_PINCON_PINMODE2_P1_8MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_8MODE_1			(1 << LPC_PINCON_PINMODE2_P1_8MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_9MODE_0			(1 << LPC_PINCON_PINMODE2_P1_9MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_9MODE_1			(1 << LPC_PINCON_PINMODE2_P1_9MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_10MODE_0			(1 << LPC_PINCON_PINMODE2_P1_10MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_10MODE_1			(1 << LPC_PINCON_PINMODE2_P1_10MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_14MODE_0			(1 << LPC_PINCON_PINMODE2_P1_14MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_14MODE_1			(1 << LPC_PINCON_PINMODE2_P1_14MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_15MODE_0			(1 << LPC_PINCON_PINMODE2_P1_15MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_15MODE_1			(1 << LPC_PINCON_PINMODE2_P1_15MODE_1_bit)

#define LPC_PINCON_PINMODE2_P1_0MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE2_P1_0MODE_bit)
#define LPC_PINCON_PINMODE2_P1_0MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE2_P1_0MODE_bit)
#define LPC_PINCON_PINMODE2_P1_0MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE2_P1_0MODE_bit)
#define LPC_PINCON_PINMODE2_P1_0MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE2_P1_0MODE_bit)

#define LPC_PINCON_PINMODE2_P1_1MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE2_P1_1MODE_bit)
#define LPC_PINCON_PINMODE2_P1_1MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE2_P1_1MODE_bit)
#define LPC_PINCON_PINMODE2_P1_1MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE2_P1_1MODE_bit)
#define LPC_PINCON_PINMODE2_P1_1MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE2_P1_1MODE_bit)

#define LPC_PINCON_PINMODE2_P1_4MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE2_P1_4MODE_bit)
#define LPC_PINCON_PINMODE2_P1_4MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE2_P1_4MODE_bit)
#define LPC_PINCON_PINMODE2_P1_4MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE2_P1_4MODE_bit)
#define LPC_PINCON_PINMODE2_P1_4MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE2_P1_4MODE_bit)

#define LPC_PINCON_PINMODE2_P1_8MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE2_P1_8MODE_bit)
#define LPC_PINCON_PINMODE2_P1_8MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE2_P1_8MODE_bit)
#define LPC_PINCON_PINMODE2_P1_8MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE2_P1_8MODE_bit)
#define LPC_PINCON_PINMODE2_P1_8MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE2_P1_8MODE_bit)

#define LPC_PINCON_PINMODE2_P1_9MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE2_P1_9MODE_bit)
#define LPC_PINCON_PINMODE2_P1_9MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE2_P1_9MODE_bit)
#define LPC_PINCON_PINMODE2_P1_9MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE2_P1_9MODE_bit)
#define LPC_PINCON_PINMODE2_P1_9MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE2_P1_9MODE_bit)

#define LPC_PINCON_PINMODE2_P1_10MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE2_P1_10MODE_bit)
#define LPC_PINCON_PINMODE2_P1_10MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE2_P1_10MODE_bit)
#define LPC_PINCON_PINMODE2_P1_10MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE2_P1_10MODE_bit)
#define LPC_PINCON_PINMODE2_P1_10MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE2_P1_10MODE_bit)

#define LPC_PINCON_PINMODE2_P1_14MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE2_P1_14MODE_bit)
#define LPC_PINCON_PINMODE2_P1_14MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE2_P1_14MODE_bit)
#define LPC_PINCON_PINMODE2_P1_14MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE2_P1_14MODE_bit)
#define LPC_PINCON_PINMODE2_P1_14MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE2_P1_14MODE_bit)

#define LPC_PINCON_PINMODE2_P1_15MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE2_P1_15MODE_bit)
#define LPC_PINCON_PINMODE2_P1_15MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE2_P1_15MODE_bit)
#define LPC_PINCON_PINMODE2_P1_15MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE2_P1_15MODE_bit)
#define LPC_PINCON_PINMODE2_P1_15MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE2_P1_15MODE_bit)

#define LPC_PINCON_PINMODE2_P1_0MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_0MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_0MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_0MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_1MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_1MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_1MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_1MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_4MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_4MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_4MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_4MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_8MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_8MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_8MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_8MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_9MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_9MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_9MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_9MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_10MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_10MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_10MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_10MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_14MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_14MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_14MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_14MODE_1_bit)
#define LPC_PINCON_PINMODE2_P1_15MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_15MODE_0_bit)
#define LPC_PINCON_PINMODE2_P1_15MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE2, LPC_PINCON_PINMODE2_P1_15MODE_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE3 - Pin Mode select register 3
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE3_P1_16MODE_bit		0
#define LPC_PINCON_PINMODE3_P1_16MODE_0_bit		0
#define LPC_PINCON_PINMODE3_P1_16MODE_1_bit		1
#define LPC_PINCON_PINMODE3_P1_17MODE_bit		2
#define LPC_PINCON_PINMODE3_P1_17MODE_0_bit		2
#define LPC_PINCON_PINMODE3_P1_17MODE_1_bit		3
#define LPC_PINCON_PINMODE3_P1_18MODE_bit		4
#define LPC_PINCON_PINMODE3_P1_18MODE_0_bit		4
#define LPC_PINCON_PINMODE3_P1_18MODE_1_bit		5
#define LPC_PINCON_PINMODE3_P1_19MODE_bit		6
#define LPC_PINCON_PINMODE3_P1_19MODE_0_bit		6
#define LPC_PINCON_PINMODE3_P1_19MODE_1_bit		7
#define LPC_PINCON_PINMODE3_P1_20MODE_bit		8
#define LPC_PINCON_PINMODE3_P1_20MODE_0_bit		8
#define LPC_PINCON_PINMODE3_P1_20MODE_1_bit		9
#define LPC_PINCON_PINMODE3_P1_21MODE_bit		10
#define LPC_PINCON_PINMODE3_P1_21MODE_0_bit		10
#define LPC_PINCON_PINMODE3_P1_21MODE_1_bit		11
#define LPC_PINCON_PINMODE3_P1_22MODE_bit		12
#define LPC_PINCON_PINMODE3_P1_22MODE_0_bit		12
#define LPC_PINCON_PINMODE3_P1_22MODE_1_bit		13
#define LPC_PINCON_PINMODE3_P1_23MODE_bit		14
#define LPC_PINCON_PINMODE3_P1_23MODE_0_bit		14
#define LPC_PINCON_PINMODE3_P1_23MODE_1_bit		15
#define LPC_PINCON_PINMODE3_P1_24MODE_bit		16
#define LPC_PINCON_PINMODE3_P1_24MODE_0_bit		16
#define LPC_PINCON_PINMODE3_P1_24MODE_1_bit		17
#define LPC_PINCON_PINMODE3_P1_25MODE_bit		18
#define LPC_PINCON_PINMODE3_P1_25MODE_0_bit		18
#define LPC_PINCON_PINMODE3_P1_25MODE_1_bit		19
#define LPC_PINCON_PINMODE3_P1_26MODE_bit		20
#define LPC_PINCON_PINMODE3_P1_26MODE_0_bit		20
#define LPC_PINCON_PINMODE3_P1_26MODE_1_bit		21
#define LPC_PINCON_PINMODE3_P1_27MODE_bit		22
#define LPC_PINCON_PINMODE3_P1_27MODE_0_bit		22
#define LPC_PINCON_PINMODE3_P1_27MODE_1_bit		23
#define LPC_PINCON_PINMODE3_P1_28MODE_bit		24
#define LPC_PINCON_PINMODE3_P1_28MODE_0_bit		24
#define LPC_PINCON_PINMODE3_P1_28MODE_1_bit		25
#define LPC_PINCON_PINMODE3_P1_29MODE_bit		26
#define LPC_PINCON_PINMODE3_P1_29MODE_0_bit		26
#define LPC_PINCON_PINMODE3_P1_29MODE_1_bit		27
#define LPC_PINCON_PINMODE3_P1_30MODE_bit		28
#define LPC_PINCON_PINMODE3_P1_30MODE_0_bit		28
#define LPC_PINCON_PINMODE3_P1_30MODE_1_bit		29
#define LPC_PINCON_PINMODE3_P1_31MODE_bit		30
#define LPC_PINCON_PINMODE3_P1_31MODE_0_bit		30
#define LPC_PINCON_PINMODE3_P1_31MODE_1_bit		31

#define LPC_PINCON_PINMODE3_P1_16MODE_0			(1 << LPC_PINCON_PINMODE3_P1_16MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_16MODE_1			(1 << LPC_PINCON_PINMODE3_P1_16MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_17MODE_0			(1 << LPC_PINCON_PINMODE3_P1_17MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_17MODE_1			(1 << LPC_PINCON_PINMODE3_P1_17MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_18MODE_0			(1 << LPC_PINCON_PINMODE3_P1_18MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_18MODE_1			(1 << LPC_PINCON_PINMODE3_P1_18MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_19MODE_0			(1 << LPC_PINCON_PINMODE3_P1_19MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_19MODE_1			(1 << LPC_PINCON_PINMODE3_P1_19MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_20MODE_0			(1 << LPC_PINCON_PINMODE3_P1_20MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_20MODE_1			(1 << LPC_PINCON_PINMODE3_P1_20MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_21MODE_0			(1 << LPC_PINCON_PINMODE3_P1_21MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_21MODE_1			(1 << LPC_PINCON_PINMODE3_P1_21MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_22MODE_0			(1 << LPC_PINCON_PINMODE3_P1_22MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_22MODE_1			(1 << LPC_PINCON_PINMODE3_P1_22MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_23MODE_0			(1 << LPC_PINCON_PINMODE3_P1_23MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_23MODE_1			(1 << LPC_PINCON_PINMODE3_P1_23MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_24MODE_0			(1 << LPC_PINCON_PINMODE3_P1_24MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_24MODE_1			(1 << LPC_PINCON_PINMODE3_P1_24MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_25MODE_0			(1 << LPC_PINCON_PINMODE3_P1_25MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_25MODE_1			(1 << LPC_PINCON_PINMODE3_P1_25MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_26MODE_0			(1 << LPC_PINCON_PINMODE3_P1_26MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_26MODE_1			(1 << LPC_PINCON_PINMODE3_P1_26MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_27MODE_0			(1 << LPC_PINCON_PINMODE3_P1_27MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_27MODE_1			(1 << LPC_PINCON_PINMODE3_P1_27MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_28MODE_0			(1 << LPC_PINCON_PINMODE3_P1_28MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_28MODE_1			(1 << LPC_PINCON_PINMODE3_P1_28MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_29MODE_0			(1 << LPC_PINCON_PINMODE3_P1_29MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_29MODE_1			(1 << LPC_PINCON_PINMODE3_P1_29MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_30MODE_0			(1 << LPC_PINCON_PINMODE3_P1_30MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_30MODE_1			(1 << LPC_PINCON_PINMODE3_P1_30MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_31MODE_0			(1 << LPC_PINCON_PINMODE3_P1_31MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_31MODE_1			(1 << LPC_PINCON_PINMODE3_P1_31MODE_1_bit)

#define LPC_PINCON_PINMODE3_P1_16MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_16MODE_bit)
#define LPC_PINCON_PINMODE3_P1_16MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_16MODE_bit)
#define LPC_PINCON_PINMODE3_P1_16MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_16MODE_bit)
#define LPC_PINCON_PINMODE3_P1_16MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_16MODE_bit)

#define LPC_PINCON_PINMODE3_P1_17MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_17MODE_bit)
#define LPC_PINCON_PINMODE3_P1_17MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_17MODE_bit)
#define LPC_PINCON_PINMODE3_P1_17MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_17MODE_bit)
#define LPC_PINCON_PINMODE3_P1_17MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_17MODE_bit)

#define LPC_PINCON_PINMODE3_P1_18MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_18MODE_bit)
#define LPC_PINCON_PINMODE3_P1_18MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_18MODE_bit)
#define LPC_PINCON_PINMODE3_P1_18MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_18MODE_bit)
#define LPC_PINCON_PINMODE3_P1_18MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_18MODE_bit)

#define LPC_PINCON_PINMODE3_P1_19MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_19MODE_bit)
#define LPC_PINCON_PINMODE3_P1_19MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_19MODE_bit)
#define LPC_PINCON_PINMODE3_P1_19MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_19MODE_bit)
#define LPC_PINCON_PINMODE3_P1_19MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_19MODE_bit)

#define LPC_PINCON_PINMODE3_P1_20MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_20MODE_bit)
#define LPC_PINCON_PINMODE3_P1_20MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_20MODE_bit)
#define LPC_PINCON_PINMODE3_P1_20MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_20MODE_bit)
#define LPC_PINCON_PINMODE3_P1_20MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_20MODE_bit)

#define LPC_PINCON_PINMODE3_P1_21MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_21MODE_bit)
#define LPC_PINCON_PINMODE3_P1_21MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_21MODE_bit)
#define LPC_PINCON_PINMODE3_P1_21MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_21MODE_bit)
#define LPC_PINCON_PINMODE3_P1_21MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_21MODE_bit)

#define LPC_PINCON_PINMODE3_P1_22MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_22MODE_bit)
#define LPC_PINCON_PINMODE3_P1_22MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_22MODE_bit)
#define LPC_PINCON_PINMODE3_P1_22MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_22MODE_bit)
#define LPC_PINCON_PINMODE3_P1_22MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_22MODE_bit)

#define LPC_PINCON_PINMODE3_P1_23MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_23MODE_bit)
#define LPC_PINCON_PINMODE3_P1_23MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_23MODE_bit)
#define LPC_PINCON_PINMODE3_P1_23MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_23MODE_bit)
#define LPC_PINCON_PINMODE3_P1_23MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_23MODE_bit)

#define LPC_PINCON_PINMODE3_P1_24MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_24MODE_bit)
#define LPC_PINCON_PINMODE3_P1_24MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_24MODE_bit)
#define LPC_PINCON_PINMODE3_P1_24MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_24MODE_bit)
#define LPC_PINCON_PINMODE3_P1_24MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_24MODE_bit)

#define LPC_PINCON_PINMODE3_P1_25MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_25MODE_bit)
#define LPC_PINCON_PINMODE3_P1_25MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_25MODE_bit)
#define LPC_PINCON_PINMODE3_P1_25MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_25MODE_bit)
#define LPC_PINCON_PINMODE3_P1_25MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_25MODE_bit)

#define LPC_PINCON_PINMODE3_P1_26MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_26MODE_bit)
#define LPC_PINCON_PINMODE3_P1_26MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_26MODE_bit)
#define LPC_PINCON_PINMODE3_P1_26MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_26MODE_bit)
#define LPC_PINCON_PINMODE3_P1_26MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_26MODE_bit)

#define LPC_PINCON_PINMODE3_P1_27MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_27MODE_bit)
#define LPC_PINCON_PINMODE3_P1_27MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_27MODE_bit)
#define LPC_PINCON_PINMODE3_P1_27MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_27MODE_bit)
#define LPC_PINCON_PINMODE3_P1_27MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_27MODE_bit)

#define LPC_PINCON_PINMODE3_P1_28MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_28MODE_bit)
#define LPC_PINCON_PINMODE3_P1_28MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_28MODE_bit)
#define LPC_PINCON_PINMODE3_P1_28MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_28MODE_bit)
#define LPC_PINCON_PINMODE3_P1_28MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_28MODE_bit)

#define LPC_PINCON_PINMODE3_P1_29MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_29MODE_bit)
#define LPC_PINCON_PINMODE3_P1_29MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_29MODE_bit)
#define LPC_PINCON_PINMODE3_P1_29MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_29MODE_bit)
#define LPC_PINCON_PINMODE3_P1_29MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_29MODE_bit)

#define LPC_PINCON_PINMODE3_P1_30MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_30MODE_bit)
#define LPC_PINCON_PINMODE3_P1_30MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_30MODE_bit)
#define LPC_PINCON_PINMODE3_P1_30MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_30MODE_bit)
#define LPC_PINCON_PINMODE3_P1_30MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_30MODE_bit)

#define LPC_PINCON_PINMODE3_P1_31MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE3_P1_31MODE_bit)
#define LPC_PINCON_PINMODE3_P1_31MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE3_P1_31MODE_bit)
#define LPC_PINCON_PINMODE3_P1_31MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE3_P1_31MODE_bit)
#define LPC_PINCON_PINMODE3_P1_31MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE3_P1_31MODE_bit)

#define LPC_PINCON_PINMODE3_P1_16MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_16MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_16MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_16MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_17MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_17MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_17MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_17MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_18MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_18MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_18MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_18MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_19MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_19MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_19MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_19MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_20MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_20MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_20MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_20MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_21MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_21MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_21MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_21MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_22MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_22MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_22MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_22MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_23MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_23MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_23MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_23MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_24MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_24MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_24MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_24MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_25MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_25MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_25MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_25MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_26MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_26MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_26MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_26MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_27MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_27MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_27MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_27MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_28MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_28MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_28MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_28MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_29MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_29MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_29MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_29MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_30MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_30MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_30MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_30MODE_1_bit)
#define LPC_PINCON_PINMODE3_P1_31MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_31MODE_0_bit)
#define LPC_PINCON_PINMODE3_P1_31MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE3, LPC_PINCON_PINMODE3_P1_31MODE_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE4 - Pin Mode select register 4
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE4_P2_0MODE_bit		0
#define LPC_PINCON_PINMODE4_P2_0MODE_0_bit		0
#define LPC_PINCON_PINMODE4_P2_0MODE_1_bit		1
#define LPC_PINCON_PINMODE4_P2_1MODE_bit		2
#define LPC_PINCON_PINMODE4_P2_1MODE_0_bit		2
#define LPC_PINCON_PINMODE4_P2_1MODE_1_bit		3
#define LPC_PINCON_PINMODE4_P2_2MODE_bit		4
#define LPC_PINCON_PINMODE4_P2_2MODE_0_bit		4
#define LPC_PINCON_PINMODE4_P2_2MODE_1_bit		5
#define LPC_PINCON_PINMODE4_P2_3MODE_bit		6
#define LPC_PINCON_PINMODE4_P2_3MODE_0_bit		6
#define LPC_PINCON_PINMODE4_P2_3MODE_1_bit		7
#define LPC_PINCON_PINMODE4_P2_4MODE_bit		8
#define LPC_PINCON_PINMODE4_P2_4MODE_0_bit		8
#define LPC_PINCON_PINMODE4_P2_4MODE_1_bit		9
#define LPC_PINCON_PINMODE4_P2_5MODE_bit		10
#define LPC_PINCON_PINMODE4_P2_5MODE_0_bit		10
#define LPC_PINCON_PINMODE4_P2_5MODE_1_bit		11
#define LPC_PINCON_PINMODE4_P2_6MODE_bit		12
#define LPC_PINCON_PINMODE4_P2_6MODE_0_bit		12
#define LPC_PINCON_PINMODE4_P2_6MODE_1_bit		13
#define LPC_PINCON_PINMODE4_P2_7MODE_bit		14
#define LPC_PINCON_PINMODE4_P2_7MODE_0_bit		14
#define LPC_PINCON_PINMODE4_P2_7MODE_1_bit		15
#define LPC_PINCON_PINMODE4_P2_8MODE_bit		16
#define LPC_PINCON_PINMODE4_P2_8MODE_0_bit		16
#define LPC_PINCON_PINMODE4_P2_8MODE_1_bit		17
#define LPC_PINCON_PINMODE4_P2_9MODE_bit		18
#define LPC_PINCON_PINMODE4_P2_9MODE_0_bit		18
#define LPC_PINCON_PINMODE4_P2_9MODE_1_bit		19
#define LPC_PINCON_PINMODE4_P2_10MODE_bit		20
#define LPC_PINCON_PINMODE4_P2_10MODE_0_bit		20
#define LPC_PINCON_PINMODE4_P2_10MODE_1_bit		21
#define LPC_PINCON_PINMODE4_P2_11MODE_bit		22
#define LPC_PINCON_PINMODE4_P2_11MODE_0_bit		22
#define LPC_PINCON_PINMODE4_P2_11MODE_1_bit		23
#define LPC_PINCON_PINMODE4_P2_12MODE_bit		24
#define LPC_PINCON_PINMODE4_P2_12MODE_0_bit		24
#define LPC_PINCON_PINMODE4_P2_12MODE_1_bit		25
#define LPC_PINCON_PINMODE4_P2_13MODE_bit		26
#define LPC_PINCON_PINMODE4_P2_13MODE_0_bit		26
#define LPC_PINCON_PINMODE4_P2_13MODE_1_bit		27

#define LPC_PINCON_PINMODE4_P2_0MODE_0			(1 << LPC_PINCON_PINMODE4_P2_0MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_0MODE_1			(1 << LPC_PINCON_PINMODE4_P2_0MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_1MODE_0			(1 << LPC_PINCON_PINMODE4_P2_1MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_1MODE_1			(1 << LPC_PINCON_PINMODE4_P2_1MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_2MODE_0			(1 << LPC_PINCON_PINMODE4_P2_2MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_2MODE_1			(1 << LPC_PINCON_PINMODE4_P2_2MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_3MODE_0			(1 << LPC_PINCON_PINMODE4_P2_3MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_3MODE_1			(1 << LPC_PINCON_PINMODE4_P2_3MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_4MODE_0			(1 << LPC_PINCON_PINMODE4_P2_4MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_4MODE_1			(1 << LPC_PINCON_PINMODE4_P2_4MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_5MODE_0			(1 << LPC_PINCON_PINMODE4_P2_5MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_5MODE_1			(1 << LPC_PINCON_PINMODE4_P2_5MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_6MODE_0			(1 << LPC_PINCON_PINMODE4_P2_6MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_6MODE_1			(1 << LPC_PINCON_PINMODE4_P2_6MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_7MODE_0			(1 << LPC_PINCON_PINMODE4_P2_7MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_7MODE_1			(1 << LPC_PINCON_PINMODE4_P2_7MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_8MODE_0			(1 << LPC_PINCON_PINMODE4_P2_8MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_8MODE_1			(1 << LPC_PINCON_PINMODE4_P2_8MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_9MODE_0			(1 << LPC_PINCON_PINMODE4_P2_9MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_9MODE_1			(1 << LPC_PINCON_PINMODE4_P2_9MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_10MODE_0			(1 << LPC_PINCON_PINMODE4_P2_10MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_10MODE_1			(1 << LPC_PINCON_PINMODE4_P2_10MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_11MODE_0			(1 << LPC_PINCON_PINMODE4_P2_11MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_11MODE_1			(1 << LPC_PINCON_PINMODE4_P2_11MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_12MODE_0			(1 << LPC_PINCON_PINMODE4_P2_12MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_12MODE_1			(1 << LPC_PINCON_PINMODE4_P2_12MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_13MODE_0			(1 << LPC_PINCON_PINMODE4_P2_13MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_13MODE_1			(1 << LPC_PINCON_PINMODE4_P2_13MODE_1_bit)

#define LPC_PINCON_PINMODE4_P2_0MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_0MODE_bit)
#define LPC_PINCON_PINMODE4_P2_0MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_0MODE_bit)
#define LPC_PINCON_PINMODE4_P2_0MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_0MODE_bit)
#define LPC_PINCON_PINMODE4_P2_0MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_0MODE_bit)

#define LPC_PINCON_PINMODE4_P2_1MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_1MODE_bit)
#define LPC_PINCON_PINMODE4_P2_1MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_1MODE_bit)
#define LPC_PINCON_PINMODE4_P2_1MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_1MODE_bit)
#define LPC_PINCON_PINMODE4_P2_1MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_1MODE_bit)

#define LPC_PINCON_PINMODE4_P2_2MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_2MODE_bit)
#define LPC_PINCON_PINMODE4_P2_2MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_2MODE_bit)
#define LPC_PINCON_PINMODE4_P2_2MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_2MODE_bit)
#define LPC_PINCON_PINMODE4_P2_2MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_2MODE_bit)

#define LPC_PINCON_PINMODE4_P2_3MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_3MODE_bit)
#define LPC_PINCON_PINMODE4_P2_3MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_3MODE_bit)
#define LPC_PINCON_PINMODE4_P2_3MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_3MODE_bit)
#define LPC_PINCON_PINMODE4_P2_3MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_3MODE_bit)

#define LPC_PINCON_PINMODE4_P2_4MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_4MODE_bit)
#define LPC_PINCON_PINMODE4_P2_4MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_4MODE_bit)
#define LPC_PINCON_PINMODE4_P2_4MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_4MODE_bit)
#define LPC_PINCON_PINMODE4_P2_4MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_4MODE_bit)

#define LPC_PINCON_PINMODE4_P2_5MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_5MODE_bit)
#define LPC_PINCON_PINMODE4_P2_5MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_5MODE_bit)
#define LPC_PINCON_PINMODE4_P2_5MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_5MODE_bit)
#define LPC_PINCON_PINMODE4_P2_5MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_5MODE_bit)

#define LPC_PINCON_PINMODE4_P2_6MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_6MODE_bit)
#define LPC_PINCON_PINMODE4_P2_6MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_6MODE_bit)
#define LPC_PINCON_PINMODE4_P2_6MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_6MODE_bit)
#define LPC_PINCON_PINMODE4_P2_6MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_6MODE_bit)

#define LPC_PINCON_PINMODE4_P2_7MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_7MODE_bit)
#define LPC_PINCON_PINMODE4_P2_7MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_7MODE_bit)
#define LPC_PINCON_PINMODE4_P2_7MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_7MODE_bit)
#define LPC_PINCON_PINMODE4_P2_7MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_7MODE_bit)

#define LPC_PINCON_PINMODE4_P2_8MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_8MODE_bit)
#define LPC_PINCON_PINMODE4_P2_8MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_8MODE_bit)
#define LPC_PINCON_PINMODE4_P2_8MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_8MODE_bit)
#define LPC_PINCON_PINMODE4_P2_8MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_8MODE_bit)

#define LPC_PINCON_PINMODE4_P2_9MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_9MODE_bit)
#define LPC_PINCON_PINMODE4_P2_9MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_9MODE_bit)
#define LPC_PINCON_PINMODE4_P2_9MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_9MODE_bit)
#define LPC_PINCON_PINMODE4_P2_9MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_9MODE_bit)

#define LPC_PINCON_PINMODE4_P2_10MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_10MODE_bit)
#define LPC_PINCON_PINMODE4_P2_10MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_10MODE_bit)
#define LPC_PINCON_PINMODE4_P2_10MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_10MODE_bit)
#define LPC_PINCON_PINMODE4_P2_10MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_10MODE_bit)

#define LPC_PINCON_PINMODE4_P2_11MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_11MODE_bit)
#define LPC_PINCON_PINMODE4_P2_11MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_11MODE_bit)
#define LPC_PINCON_PINMODE4_P2_11MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_11MODE_bit)
#define LPC_PINCON_PINMODE4_P2_11MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_11MODE_bit)

#define LPC_PINCON_PINMODE4_P2_12MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_12MODE_bit)
#define LPC_PINCON_PINMODE4_P2_12MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_12MODE_bit)
#define LPC_PINCON_PINMODE4_P2_12MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_12MODE_bit)
#define LPC_PINCON_PINMODE4_P2_12MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_12MODE_bit)

#define LPC_PINCON_PINMODE4_P2_13MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE4_P2_13MODE_bit)
#define LPC_PINCON_PINMODE4_P2_13MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE4_P2_13MODE_bit)
#define LPC_PINCON_PINMODE4_P2_13MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE4_P2_13MODE_bit)
#define LPC_PINCON_PINMODE4_P2_13MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE4_P2_13MODE_bit)

#define LPC_PINCON_PINMODE4_P2_0MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_0MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_0MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_0MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_1MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_1MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_1MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_1MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_2MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_2MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_2MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_2MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_3MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_3MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_3MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_3MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_4MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_4MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_4MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_4MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_5MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_5MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_5MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_5MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_6MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_6MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_6MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_6MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_7MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_7MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_7MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_7MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_8MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_8MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_8MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_8MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_9MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_9MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_9MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_9MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_10MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_10MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_10MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_10MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_11MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_11MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_11MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_11MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_12MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_12MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_12MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_12MODE_1_bit)
#define LPC_PINCON_PINMODE4_P2_13MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_13MODE_0_bit)
#define LPC_PINCON_PINMODE4_P2_13MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE4, LPC_PINCON_PINMODE4_P2_13MODE_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE7 - Pin Mode select register 7
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE7_P3_25MODE_bit		18
#define LPC_PINCON_PINMODE7_P3_25MODE_0_bit		18
#define LPC_PINCON_PINMODE7_P3_25MODE_1_bit		19
#define LPC_PINCON_PINMODE7_P3_26MODE_bit		20
#define LPC_PINCON_PINMODE7_P3_26MODE_0_bit		20
#define LPC_PINCON_PINMODE7_P3_26MODE_1_bit		21

#define LPC_PINCON_PINMODE7_P3_25MODE_0			(1 << LPC_PINCON_PINMODE7_P3_25MODE_0_bit)
#define LPC_PINCON_PINMODE7_P3_25MODE_1			(1 << LPC_PINCON_PINMODE7_P3_25MODE_1_bit)
#define LPC_PINCON_PINMODE7_P3_26MODE_0			(1 << LPC_PINCON_PINMODE7_P3_26MODE_0_bit)
#define LPC_PINCON_PINMODE7_P3_26MODE_1			(1 << LPC_PINCON_PINMODE7_P3_26MODE_1_bit)

#define LPC_PINCON_PINMODE7_P3_25MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE7_P3_25MODE_bit)
#define LPC_PINCON_PINMODE7_P3_25MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE7_P3_25MODE_bit)
#define LPC_PINCON_PINMODE7_P3_25MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE7_P3_25MODE_bit)
#define LPC_PINCON_PINMODE7_P3_25MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE7_P3_25MODE_bit)

#define LPC_PINCON_PINMODE7_P3_26MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE7_P3_26MODE_bit)
#define LPC_PINCON_PINMODE7_P3_26MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE7_P3_26MODE_bit)
#define LPC_PINCON_PINMODE7_P3_26MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE7_P3_26MODE_bit)
#define LPC_PINCON_PINMODE7_P3_26MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE7_P3_26MODE_bit)

#define LPC_PINCON_PINMODE7_P3_25MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE7, LPC_PINCON_PINMODE7_P3_25MODE_0_bit)
#define LPC_PINCON_PINMODE7_P3_25MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE7, LPC_PINCON_PINMODE7_P3_25MODE_1_bit)
#define LPC_PINCON_PINMODE7_P3_26MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE7, LPC_PINCON_PINMODE7_P3_26MODE_0_bit)
#define LPC_PINCON_PINMODE7_P3_26MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE7, LPC_PINCON_PINMODE7_P3_26MODE_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE9 - Pin Mode select register 9
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE9_P4_28MODE_bit		24
#define LPC_PINCON_PINMODE9_P4_28MODE_0_bit		24
#define LPC_PINCON_PINMODE9_P4_28MODE_1_bit		25
#define LPC_PINCON_PINMODE9_P4_29MODE_bit		26
#define LPC_PINCON_PINMODE9_P4_29MODE_0_bit		26
#define LPC_PINCON_PINMODE9_P4_29MODE_1_bit		27

#define LPC_PINCON_PINMODE9_P4_28MODE_0			(1 << LPC_PINCON_PINMODE9_P4_28MODE_0_bit)
#define LPC_PINCON_PINMODE9_P4_28MODE_1			(1 << LPC_PINCON_PINMODE9_P4_28MODE_1_bit)
#define LPC_PINCON_PINMODE9_P4_29MODE_0			(1 << LPC_PINCON_PINMODE9_P4_29MODE_0_bit)
#define LPC_PINCON_PINMODE9_P4_29MODE_1			(1 << LPC_PINCON_PINMODE9_P4_29MODE_1_bit)

#define LPC_PINCON_PINMODE9_P4_28MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE9_P4_28MODE_bit)
#define LPC_PINCON_PINMODE9_P4_28MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE9_P4_28MODE_bit)
#define LPC_PINCON_PINMODE9_P4_28MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE9_P4_28MODE_bit)
#define LPC_PINCON_PINMODE9_P4_28MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE9_P4_28MODE_bit)

#define LPC_PINCON_PINMODE9_P4_29MODE_PULL_UP		(LPC_PINCON_PINMODEx_PULL_UP_value << LPC_PINCON_PINMODE9_P4_29MODE_bit)
#define LPC_PINCON_PINMODE9_P4_29MODE_REPEATER		(LPC_PINCON_PINMODEx_REPEATER_value << LPC_PINCON_PINMODE9_P4_29MODE_bit)
#define LPC_PINCON_PINMODE9_P4_29MODE_FLOATING		(LPC_PINCON_PINMODEx_FLOATING_value << LPC_PINCON_PINMODE9_P4_29MODE_bit)
#define LPC_PINCON_PINMODE9_P4_29MODE_PULL_DOWN		(LPC_PINCON_PINMODEx_PULL_DOWN_value << LPC_PINCON_PINMODE9_P4_29MODE_bit)

#define LPC_PINCON_PINMODE9_P4_28MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE9, LPC_PINCON_PINMODE9_P4_28MODE_0_bit)
#define LPC_PINCON_PINMODE9_P4_28MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE9, LPC_PINCON_PINMODE9_P4_28MODE_1_bit)
#define LPC_PINCON_PINMODE9_P4_29MODE_0_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE9, LPC_PINCON_PINMODE9_P4_29MODE_0_bit)
#define LPC_PINCON_PINMODE9_P4_29MODE_1_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE9, LPC_PINCON_PINMODE9_P4_29MODE_1_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE_OD0 - Open Drain Pin Mode select register 0
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE_OD0_P0_0OD_bit		0
#define LPC_PINCON_PINMODE_OD0_P0_1OD_bit		1
#define LPC_PINCON_PINMODE_OD0_P0_2OD_bit		2
#define LPC_PINCON_PINMODE_OD0_P0_3OD_bit		3
#define LPC_PINCON_PINMODE_OD0_P0_4OD_bit		4
#define LPC_PINCON_PINMODE_OD0_P0_5OD_bit		5
#define LPC_PINCON_PINMODE_OD0_P0_6OD_bit		6
#define LPC_PINCON_PINMODE_OD0_P0_7OD_bit		7
#define LPC_PINCON_PINMODE_OD0_P0_8OD_bit		8
#define LPC_PINCON_PINMODE_OD0_P0_9OD_bit		9
#define LPC_PINCON_PINMODE_OD0_P0_10OD_bit		10
#define LPC_PINCON_PINMODE_OD0_P0_11OD_bit		11
#define LPC_PINCON_PINMODE_OD0_P0_15OD_bit		15
#define LPC_PINCON_PINMODE_OD0_P0_16OD_bit		16
#define LPC_PINCON_PINMODE_OD0_P0_17OD_bit		17
#define LPC_PINCON_PINMODE_OD0_P0_18OD_bit		18
#define LPC_PINCON_PINMODE_OD0_P0_19OD_bit		19
#define LPC_PINCON_PINMODE_OD0_P0_20OD_bit		20
#define LPC_PINCON_PINMODE_OD0_P0_21OD_bit		21
#define LPC_PINCON_PINMODE_OD0_P0_22OD_bit		22
#define LPC_PINCON_PINMODE_OD0_P0_23OD_bit		23
#define LPC_PINCON_PINMODE_OD0_P0_24OD_bit		24
#define LPC_PINCON_PINMODE_OD0_P0_25OD_bit		25
#define LPC_PINCON_PINMODE_OD0_P0_26OD_bit		26
#define LPC_PINCON_PINMODE_OD0_P0_29OD_bit		29
#define LPC_PINCON_PINMODE_OD0_P0_30OD_bit		30

#define LPC_PINCON_PINMODE_OD0_P0_0OD			(1 << LPC_PINCON_PINMODE_OD0_P0_0OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_1OD			(1 << LPC_PINCON_PINMODE_OD0_P0_1OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_2OD			(1 << LPC_PINCON_PINMODE_OD0_P0_2OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_3OD			(1 << LPC_PINCON_PINMODE_OD0_P0_3OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_4OD			(1 << LPC_PINCON_PINMODE_OD0_P0_4OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_5OD			(1 << LPC_PINCON_PINMODE_OD0_P0_5OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_6OD			(1 << LPC_PINCON_PINMODE_OD0_P0_6OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_7OD			(1 << LPC_PINCON_PINMODE_OD0_P0_7OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_8OD			(1 << LPC_PINCON_PINMODE_OD0_P0_8OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_9OD			(1 << LPC_PINCON_PINMODE_OD0_P0_9OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_10OD			(1 << LPC_PINCON_PINMODE_OD0_P0_10OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_11OD			(1 << LPC_PINCON_PINMODE_OD0_P0_11OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_15OD			(1 << LPC_PINCON_PINMODE_OD0_P0_15OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_16OD			(1 << LPC_PINCON_PINMODE_OD0_P0_16OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_17OD			(1 << LPC_PINCON_PINMODE_OD0_P0_17OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_18OD			(1 << LPC_PINCON_PINMODE_OD0_P0_18OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_19OD			(1 << LPC_PINCON_PINMODE_OD0_P0_19OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_20OD			(1 << LPC_PINCON_PINMODE_OD0_P0_20OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_21OD			(1 << LPC_PINCON_PINMODE_OD0_P0_21OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_22OD			(1 << LPC_PINCON_PINMODE_OD0_P0_22OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_23OD			(1 << LPC_PINCON_PINMODE_OD0_P0_23OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_24OD			(1 << LPC_PINCON_PINMODE_OD0_P0_24OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_25OD			(1 << LPC_PINCON_PINMODE_OD0_P0_25OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_26OD			(1 << LPC_PINCON_PINMODE_OD0_P0_26OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_29OD			(1 << LPC_PINCON_PINMODE_OD0_P0_29OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_30OD			(1 << LPC_PINCON_PINMODE_OD0_P0_30OD_bit)

#define LPC_PINCON_PINMODE_OD0_P0_0OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_0OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_1OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_1OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_2OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_2OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_3OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_3OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_4OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_4OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_5OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_5OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_6OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_6OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_7OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_7OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_8OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_8OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_9OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_9OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_10OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_10OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_11OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_11OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_15OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_15OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_16OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_16OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_17OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_17OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_18OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_18OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_19OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_19OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_20OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_20OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_21OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_21OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_22OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_22OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_23OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_23OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_24OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_24OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_25OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_25OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_26OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_26OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_29OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_29OD_bit)
#define LPC_PINCON_PINMODE_OD0_P0_30OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD0, LPC_PINCON_PINMODE_OD0_P0_30OD_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE_OD1 - Open Drain Pin Mode select register 1
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE_OD1_P1_0OD_bit		0
#define LPC_PINCON_PINMODE_OD1_P1_1OD_bit		1
#define LPC_PINCON_PINMODE_OD1_P1_4OD_bit		4
#define LPC_PINCON_PINMODE_OD1_P1_8OD_bit		8
#define LPC_PINCON_PINMODE_OD1_P1_9OD_bit		9
#define LPC_PINCON_PINMODE_OD1_P1_10OD_bit		10
#define LPC_PINCON_PINMODE_OD1_P1_14OD_bit		14
#define LPC_PINCON_PINMODE_OD1_P1_15OD_bit		15
#define LPC_PINCON_PINMODE_OD1_P1_16OD_bit		16
#define LPC_PINCON_PINMODE_OD1_P1_17OD_bit		17
#define LPC_PINCON_PINMODE_OD1_P1_18OD_bit		18
#define LPC_PINCON_PINMODE_OD1_P1_19OD_bit		19
#define LPC_PINCON_PINMODE_OD1_P1_20OD_bit		20
#define LPC_PINCON_PINMODE_OD1_P1_21OD_bit		21
#define LPC_PINCON_PINMODE_OD1_P1_22OD_bit		22
#define LPC_PINCON_PINMODE_OD1_P1_23OD_bit		23
#define LPC_PINCON_PINMODE_OD1_P1_24OD_bit		24
#define LPC_PINCON_PINMODE_OD1_P1_25OD_bit		25
#define LPC_PINCON_PINMODE_OD1_P1_26OD_bit		26
#define LPC_PINCON_PINMODE_OD1_P1_27OD_bit		27
#define LPC_PINCON_PINMODE_OD1_P1_28OD_bit		28
#define LPC_PINCON_PINMODE_OD1_P1_29OD_bit		29
#define LPC_PINCON_PINMODE_OD1_P1_30OD_bit		30
#define LPC_PINCON_PINMODE_OD1_P1_31OD_bit		31

#define LPC_PINCON_PINMODE_OD1_P1_0OD			(1 << LPC_PINCON_PINMODE_OD1_P1_0OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_1OD			(1 << LPC_PINCON_PINMODE_OD1_P1_1OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_4OD			(1 << LPC_PINCON_PINMODE_OD1_P1_4OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_8OD			(1 << LPC_PINCON_PINMODE_OD1_P1_8OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_9OD			(1 << LPC_PINCON_PINMODE_OD1_P1_9OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_10OD			(1 << LPC_PINCON_PINMODE_OD1_P1_10OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_14OD			(1 << LPC_PINCON_PINMODE_OD1_P1_14OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_15OD			(1 << LPC_PINCON_PINMODE_OD1_P1_15OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_16OD			(1 << LPC_PINCON_PINMODE_OD1_P1_16OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_17OD			(1 << LPC_PINCON_PINMODE_OD1_P1_17OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_18OD			(1 << LPC_PINCON_PINMODE_OD1_P1_18OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_19OD			(1 << LPC_PINCON_PINMODE_OD1_P1_19OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_20OD			(1 << LPC_PINCON_PINMODE_OD1_P1_20OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_21OD			(1 << LPC_PINCON_PINMODE_OD1_P1_21OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_22OD			(1 << LPC_PINCON_PINMODE_OD1_P1_22OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_23OD			(1 << LPC_PINCON_PINMODE_OD1_P1_23OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_24OD			(1 << LPC_PINCON_PINMODE_OD1_P1_24OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_25OD			(1 << LPC_PINCON_PINMODE_OD1_P1_25OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_26OD			(1 << LPC_PINCON_PINMODE_OD1_P1_26OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_27OD			(1 << LPC_PINCON_PINMODE_OD1_P1_27OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_28OD			(1 << LPC_PINCON_PINMODE_OD1_P1_28OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_29OD			(1 << LPC_PINCON_PINMODE_OD1_P1_29OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_30OD			(1 << LPC_PINCON_PINMODE_OD1_P1_30OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_31OD			(1 << LPC_PINCON_PINMODE_OD1_P1_31OD_bit)

#define LPC_PINCON_PINMODE_OD1_P1_0OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_0OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_1OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_1OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_4OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_4OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_8OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_8OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_9OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_9OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_10OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_10OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_14OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_14OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_15OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_15OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_16OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_16OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_17OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_17OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_18OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_18OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_19OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_19OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_20OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_20OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_21OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_21OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_22OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_22OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_23OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_23OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_24OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_24OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_25OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_25OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_26OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_26OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_27OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_27OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_28OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_28OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_29OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_29OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_30OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_30OD_bit)
#define LPC_PINCON_PINMODE_OD1_P1_31OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD1, LPC_PINCON_PINMODE_OD1_P1_31OD_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE_OD2 - Open Drain Pin Mode select register 2
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE_OD2_P2_0OD_bit		0
#define LPC_PINCON_PINMODE_OD2_P2_1OD_bit		1
#define LPC_PINCON_PINMODE_OD2_P2_2OD_bit		2
#define LPC_PINCON_PINMODE_OD2_P2_3OD_bit		3
#define LPC_PINCON_PINMODE_OD2_P2_4OD_bit		4
#define LPC_PINCON_PINMODE_OD2_P2_5OD_bit		5
#define LPC_PINCON_PINMODE_OD2_P2_6OD_bit		6
#define LPC_PINCON_PINMODE_OD2_P2_7OD_bit		7
#define LPC_PINCON_PINMODE_OD2_P2_8OD_bit		8
#define LPC_PINCON_PINMODE_OD2_P2_9OD_bit		9
#define LPC_PINCON_PINMODE_OD2_P2_10OD_bit		10
#define LPC_PINCON_PINMODE_OD2_P2_11OD_bit		11
#define LPC_PINCON_PINMODE_OD2_P2_12OD_bit		12
#define LPC_PINCON_PINMODE_OD2_P2_13OD_bit		13

#define LPC_PINCON_PINMODE_OD2_P2_0OD			(1 << LPC_PINCON_PINMODE_OD2_P2_0OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_1OD			(1 << LPC_PINCON_PINMODE_OD2_P2_1OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_2OD			(1 << LPC_PINCON_PINMODE_OD2_P2_2OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_3OD			(1 << LPC_PINCON_PINMODE_OD2_P2_3OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_4OD			(1 << LPC_PINCON_PINMODE_OD2_P2_4OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_5OD			(1 << LPC_PINCON_PINMODE_OD2_P2_5OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_6OD			(1 << LPC_PINCON_PINMODE_OD2_P2_6OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_7OD			(1 << LPC_PINCON_PINMODE_OD2_P2_7OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_8OD			(1 << LPC_PINCON_PINMODE_OD2_P2_8OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_9OD			(1 << LPC_PINCON_PINMODE_OD2_P2_9OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_10OD			(1 << LPC_PINCON_PINMODE_OD2_P2_10OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_11OD			(1 << LPC_PINCON_PINMODE_OD2_P2_11OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_12OD			(1 << LPC_PINCON_PINMODE_OD2_P2_12OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_13OD			(1 << LPC_PINCON_PINMODE_OD2_P2_13OD_bit)

#define LPC_PINCON_PINMODE_OD2_P2_0OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_0OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_1OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_1OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_2OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_2OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_3OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_3OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_4OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_4OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_5OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_5OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_6OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_6OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_7OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_7OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_8OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_8OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_9OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_9OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_10OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_10OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_11OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_11OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_12OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_12OD_bit)
#define LPC_PINCON_PINMODE_OD2_P2_13OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD2, LPC_PINCON_PINMODE_OD2_P2_13OD_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE_OD3 - Open Drain Pin Mode select register 3
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE_OD3_P3_25OD_bit		25
#define LPC_PINCON_PINMODE_OD3_P3_26OD_bit		26

#define LPC_PINCON_PINMODE_OD3_P3_25OD			(1 << LPC_PINCON_PINMODE_OD3_P3_25OD_bit)
#define LPC_PINCON_PINMODE_OD3_P3_26OD			(1 << LPC_PINCON_PINMODE_OD3_P3_26OD_bit)

#define LPC_PINCON_PINMODE_OD3_P3_25OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD3, LPC_PINCON_PINMODE_OD3_P3_25OD_bit)
#define LPC_PINCON_PINMODE_OD3_P3_26OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD3, LPC_PINCON_PINMODE_OD3_P3_26OD_bit)

/*
+-----------------------------------------------------------------------------+
| PINMODE_OD4 - Open Drain Pin Mode select register 4
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_PINMODE_OD4_P4_28OD_bit		28
#define LPC_PINCON_PINMODE_OD4_P4_29OD_bit		29

#define LPC_PINCON_PINMODE_OD4_P4_28OD			(1 << LPC_PINCON_PINMODE_OD4_P4_28OD_bit)
#define LPC_PINCON_PINMODE_OD4_P4_29OD			(1 << LPC_PINCON_PINMODE_OD4_P4_29OD_bit)

#define LPC_PINCON_PINMODE_OD4_P4_28OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD4, LPC_PINCON_PINMODE_OD4_P4_28OD_bit)
#define LPC_PINCON_PINMODE_OD4_P4_29OD_bb		bitband_t BITBAND(&LPC_PINCON->PINMODE_OD4, LPC_PINCON_PINMODE_OD4_P4_29OD_bit)

/*
+-----------------------------------------------------------------------------+
| I2CPADCFG - I2C Pin Configuration register
+-----------------------------------------------------------------------------+
*/

#define LPC_PINCON_I2CPADCFG_SDADRV0_bit		0
#define LPC_PINCON_I2CPADCFG_SDAI2C0_bit		1
#define LPC_PINCON_I2CPADCFG_SCLDRV0_bit		2
#define LPC_PINCON_I2CPADCFG_SCLI2C0_bit		3

#define LPC_PINCON_I2CPADCFG_SDADRV0			(1 << LPC_PINCON_I2CPADCFG_SDADRV0_bit)
#define LPC_PINCON_I2CPADCFG_SDAI2C0			(1 << LPC_PINCON_I2CPADCFG_SDAI2C0_bit)
#define LPC_PINCON_I2CPADCFG_SCLDRV0			(1 << LPC_PINCON_I2CPADCFG_SCLDRV0_bit)
#define LPC_PINCON_I2CPADCFG_SCLI2C0			(1 << LPC_PINCON_I2CPADCFG_SCLI2C0_bit)

#define LPC_PINCON_I2CPADCFG_SDADRV0_bb			bitband_t BITBAND(&LPC_PINCON->I2CPADCFG, LPC_PINCON_I2CPADCFG_SDADRV0_bit)
#define LPC_PINCON_I2CPADCFG_SDAI2C0_bb			bitband_t BITBAND(&LPC_PINCON->I2CPADCFG, LPC_PINCON_I2CPADCFG_SDAI2C0_bit)
#define LPC_PINCON_I2CPADCFG_SCLDRV0_bb			bitband_t BITBAND(&LPC_PINCON->I2CPADCFG, LPC_PINCON_I2CPADCFG_SCLDRV0_bit)
#define LPC_PINCON_I2CPADCFG_SCLI2C0_bb			bitband_t BITBAND(&LPC_PINCON->I2CPADCFG, LPC_PINCON_I2CPADCFG_SCLI2C0_bit)

/******************************************************************************
* END OF FILE
******************************************************************************/
#endif /* HDR_PINCON_H_ */
